@@ -24,38 +24,20 @@
 
 #include "P_Cache.h"
 #include "P_CacheTest.h"
-#include "api/ts/ts.h"
 #include <vector>
 #include <cmath>
+#include <cstdlib>
 
-CacheTestSM::CacheTestSM(RegressionTest *t, const char *name)
-  : RegressionSM(t),
-    start_memcpy_on_clone(0),
-    cache_test_name(name),
-    timeout(nullptr),
-    cache_action(nullptr),
-    start_time(0),
-    cache_vc(nullptr),
-    cvio(nullptr),
-    buffer(nullptr),
-    buffer_reader(nullptr),
-    total_size(0),
-    nbytes(-1),
-    repeat_count(0),
-    expect_event(EVENT_NONE),
-    expect_initial_event(EVENT_NONE),
-    initial_event(EVENT_NONE),
-    content_salt(0),
-    end_memcpy_on_clone(0)
+CacheTestSM::CacheTestSM(RegressionTest *t, const char *name) : RegressionSM(t), cache_test_name(name)
 {
   SET_HANDLER(&CacheTestSM::event_handler);
 }
 
 CacheTestSM::CacheTestSM(const CacheTestSM &ao) : RegressionSM(ao)
 {
-  int o = (int)(((char *)&start_memcpy_on_clone) - ((char *)this));
-  int s = (int)(((char *)&end_memcpy_on_clone) - ((char *)&start_memcpy_on_clone));
-  memcpy(((char *)this) + o, ((char *)&ao) + o, s);
+  int o = static_cast<int>((reinterpret_cast<char *>(&start_memcpy_on_clone)) - (reinterpret_cast<char *>(this)));
+  int s = static_cast<int>((reinterpret_cast<char *>(&end_memcpy_on_clone)) - (reinterpret_cast<char *>(&start_memcpy_on_clone)));
+  memcpy((reinterpret_cast<char *>(this)) + o, ((char *)&ao) + o, s);
   SET_HANDLER(&CacheTestSM::event_handler);
 }
 
@@ -63,10 +45,12 @@ CacheTestSM::~CacheTestSM()
 {
   ink_assert(!cache_action);
   ink_assert(!cache_vc);
-  if (buffer_reader)
+  if (buffer_reader) {
     buffer->dealloc_reader(buffer_reader);
-  if (buffer)
+  }
+  if (buffer) {
     free_MIOBuffer(buffer);
+  }
 }
 
 int
@@ -110,27 +94,30 @@ CacheTestSM::event_handler(int event, void *data)
     initial_event = event;
     cancel_timeout();
     cache_action  = nullptr;
-    cache_vc      = (CacheVConnection *)data;
-    buffer        = new_empty_MIOBuffer();
+    cache_vc      = static_cast<CacheVConnection *>(data);
+    buffer        = new_empty_MIOBuffer(BUFFER_SIZE_INDEX_32K);
     buffer_reader = buffer->alloc_reader();
-    if (open_read_callout() < 0)
+    if (open_read_callout() < 0) {
       goto Lclose_error_next;
-    else
+    } else {
       return EVENT_DONE;
+    }
 
   case CACHE_EVENT_OPEN_READ_FAILED:
     goto Lcancel_next;
 
   case VC_EVENT_READ_READY:
-    if (!check_buffer())
+    if (!check_buffer()) {
       goto Lclose_error_next;
+    }
     buffer_reader->consume(buffer_reader->read_avail());
-    ((VIO *)data)->reenable();
+    (static_cast<VIO *>(data))->reenable();
     return EVENT_CONT;
 
   case VC_EVENT_READ_COMPLETE:
-    if (!check_buffer())
+    if (!check_buffer()) {
       goto Lclose_error_next;
+    }
     goto Lclose_next;
 
   case VC_EVENT_ERROR:
@@ -141,13 +128,14 @@ CacheTestSM::event_handler(int event, void *data)
     initial_event = event;
     cancel_timeout();
     cache_action  = nullptr;
-    cache_vc      = (CacheVConnection *)data;
-    buffer        = new_empty_MIOBuffer();
+    cache_vc      = static_cast<CacheVConnection *>(data);
+    buffer        = new_empty_MIOBuffer(BUFFER_SIZE_INDEX_32K);
     buffer_reader = buffer->alloc_reader();
-    if (open_write_callout() < 0)
+    if (open_write_callout() < 0) {
       goto Lclose_error_next;
-    else
+    } else {
       return EVENT_DONE;
+    }
 
   case CACHE_EVENT_OPEN_WRITE_FAILED:
     goto Lcancel_next;
@@ -158,8 +146,9 @@ CacheTestSM::event_handler(int event, void *data)
     return EVENT_CONT;
 
   case VC_EVENT_WRITE_COMPLETE:
-    if (nbytes != cvio->ndone)
+    if (nbytes != cvio->ndone) {
       goto Lclose_error_next;
+    }
     goto Lclose_next;
 
   case CACHE_EVENT_REMOVE:
@@ -168,7 +157,7 @@ CacheTestSM::event_handler(int event, void *data)
 
   case CACHE_EVENT_SCAN:
     initial_event = event;
-    cache_vc      = (CacheVConnection *)data;
+    cache_vc      = static_cast<CacheVConnection *>(data);
     return EVENT_CONT;
 
   case CACHE_EVENT_SCAN_OBJECT:
@@ -219,8 +208,9 @@ Lnext:
     repeat_count--;
     timeout = eventProcessor.schedule_imm(this);
     return EVENT_DONE;
-  } else
+  } else {
     return complete(event);
+  }
 }
 
 void
@@ -229,19 +219,21 @@ CacheTestSM::fill_buffer()
   int64_t avail = buffer->write_avail();
   CacheKey k    = key;
   k.b[1] += content_salt;
-  int64_t sk = (int64_t)sizeof(key);
+  int64_t sk = static_cast<int64_t>(sizeof(key));
   while (avail > 0) {
     int64_t l = avail;
-    if (l > sk)
+    if (l > sk) {
       l = sk;
+    }
 
     int64_t pos = cvio->ndone + buffer_reader->read_avail();
     int64_t o   = pos % sk;
 
-    if (l > sk - o)
-      l     = sk - o;
+    if (l > sk - o) {
+      l = sk - o;
+    }
     k.b[0]  = pos / sk;
-    char *x = ((char *)&k) + o;
+    char *x = (reinterpret_cast<char *>(&k)) + o;
     buffer->write(x, l);
     buffer->fill(l);
     avail -= l;
@@ -255,20 +247,23 @@ CacheTestSM::check_buffer()
   CacheKey k    = key;
   k.b[1] += content_salt;
   char b[sizeof(key)];
-  int64_t sk  = (int64_t)sizeof(key);
+  int64_t sk  = static_cast<int64_t>(sizeof(key));
   int64_t pos = cvio->ndone - buffer_reader->read_avail();
   while (avail > 0) {
     int64_t l = avail;
-    if (l > sk)
-      l       = sk;
+    if (l > sk) {
+      l = sk;
+    }
     int64_t o = pos % sk;
-    if (l > sk - o)
-      l     = sk - o;
+    if (l > sk - o) {
+      l = sk - o;
+    }
     k.b[0]  = pos / sk;
-    char *x = ((char *)&k) + o;
+    char *x = (reinterpret_cast<char *>(&k)) + o;
     buffer_reader->read(&b[0], l);
-    if (::memcmp(b, x, l))
+    if (::memcmp(b, x, l)) {
       return 0;
+    }
     buffer_reader->consume(l);
     pos += l;
     avail -= l;
@@ -285,10 +280,11 @@ CacheTestSM::check_result(int event)
 int
 CacheTestSM::complete(int event)
 {
-  if (!check_result(event))
+  if (!check_result(event)) {
     done(REGRESSION_TEST_FAILED);
-  else
+  } else {
     done(REGRESSION_TEST_PASSED);
+  }
   delete this;
   return EVENT_DONE;
 }
@@ -303,41 +299,41 @@ EXCLUSIVE_REGRESSION_TEST(cache)(RegressionTest *t, int /* atype ATS_UNUSED */,
 
   EThread *thread = this_ethread();
 
-  CACHE_SM(t, write_test, { cacheProcessor.open_write(this, &key, false, CACHE_FRAG_TYPE_NONE, 100, CACHE_WRITE_OPT_SYNC); });
+  CACHE_SM(t, write_test, { cacheProcessor.open_write(this, &key, CACHE_FRAG_TYPE_NONE, 100, CACHE_WRITE_OPT_SYNC); });
   write_test.expect_initial_event = CACHE_EVENT_OPEN_WRITE;
   write_test.expect_event         = VC_EVENT_WRITE_COMPLETE;
   write_test.nbytes               = 100;
   rand_CacheKey(&write_test.key, thread->mutex);
 
-  CACHE_SM(t, lookup_test, { cacheProcessor.lookup(this, &key, false); });
+  CACHE_SM(t, lookup_test, { cacheProcessor.lookup(this, &key); });
   lookup_test.expect_event = CACHE_EVENT_LOOKUP;
   lookup_test.key          = write_test.key;
 
-  CACHE_SM(t, read_test, { cacheProcessor.open_read(this, &key, false); });
+  CACHE_SM(t, read_test, { cacheProcessor.open_read(this, &key); });
   read_test.expect_initial_event = CACHE_EVENT_OPEN_READ;
   read_test.expect_event         = VC_EVENT_READ_COMPLETE;
   read_test.nbytes               = 100;
   read_test.key                  = write_test.key;
 
-  CACHE_SM(t, remove_test, { cacheProcessor.remove(this, &key, false); });
+  CACHE_SM(t, remove_test, { cacheProcessor.remove(this, &key); });
   remove_test.expect_event = CACHE_EVENT_REMOVE;
   remove_test.key          = write_test.key;
 
-  CACHE_SM(t, lookup_fail_test, { cacheProcessor.lookup(this, &key, false); });
+  CACHE_SM(t, lookup_fail_test, { cacheProcessor.lookup(this, &key); });
   lookup_fail_test.expect_event = CACHE_EVENT_LOOKUP_FAILED;
   lookup_fail_test.key          = write_test.key;
 
-  CACHE_SM(t, read_fail_test, { cacheProcessor.open_read(this, &key, false); });
+  CACHE_SM(t, read_fail_test, { cacheProcessor.open_read(this, &key); });
   read_fail_test.expect_event = CACHE_EVENT_OPEN_READ_FAILED;
   read_fail_test.key          = write_test.key;
 
-  CACHE_SM(t, remove_fail_test, { cacheProcessor.remove(this, &key, false); });
+  CACHE_SM(t, remove_fail_test, { cacheProcessor.remove(this, &key); });
   remove_fail_test.expect_event = CACHE_EVENT_REMOVE_FAILED;
   rand_CacheKey(&remove_fail_test.key, thread->mutex);
 
   CACHE_SM(
     t, replace_write_test,
-    { cacheProcessor.open_write(this, &key, false, CACHE_FRAG_TYPE_NONE, 100, CACHE_WRITE_OPT_SYNC); } int open_write_callout() {
+    { cacheProcessor.open_write(this, &key, CACHE_FRAG_TYPE_NONE, 100, CACHE_WRITE_OPT_SYNC); } int open_write_callout() override {
       header.serial = 10;
       cache_vc->set_header(&header, sizeof(header));
       cvio = cache_vc->do_io_write(this, nbytes, buffer_reader);
@@ -348,53 +344,55 @@ EXCLUSIVE_REGRESSION_TEST(cache)(RegressionTest *t, int /* atype ATS_UNUSED */,
   replace_write_test.nbytes               = 100;
   rand_CacheKey(&replace_write_test.key, thread->mutex);
 
-  CACHE_SM(t, replace_test,
-           {
-             cacheProcessor.open_write(this, &key, false, CACHE_FRAG_TYPE_NONE, 100, CACHE_WRITE_OPT_OVERWRITE_SYNC);
-           } int open_write_callout() {
-             CacheTestHeader *h = nullptr;
-             int hlen           = 0;
-             if (cache_vc->get_header((void **)&h, &hlen) < 0)
-               return -1;
-             if (h->serial != 10)
-               return -1;
-             header.serial = 11;
-             cache_vc->set_header(&header, sizeof(header));
-             cvio = cache_vc->do_io_write(this, nbytes, buffer_reader);
-             return 1;
-           });
+  CACHE_SM(
+    t, replace_test,
+    { cacheProcessor.open_write(this, &key, CACHE_FRAG_TYPE_NONE, 100, CACHE_WRITE_OPT_OVERWRITE_SYNC); } int open_write_callout()
+      override {
+        CacheTestHeader *h = nullptr;
+        int hlen           = 0;
+        if (cache_vc->get_header((void **)&h, &hlen) < 0)
+          return -1;
+        if (h->serial != 10)
+          return -1;
+        header.serial = 11;
+        cache_vc->set_header(&header, sizeof(header));
+        cvio = cache_vc->do_io_write(this, nbytes, buffer_reader);
+        return 1;
+      });
   replace_test.expect_initial_event = CACHE_EVENT_OPEN_WRITE;
   replace_test.expect_event         = VC_EVENT_WRITE_COMPLETE;
   replace_test.nbytes               = 100;
   replace_test.key                  = replace_write_test.key;
   replace_test.content_salt         = 1;
 
-  CACHE_SM(t, replace_read_test, { cacheProcessor.open_read(this, &key, false); } int open_read_callout() {
-    CacheTestHeader *h = nullptr;
-    int hlen           = 0;
-    if (cache_vc->get_header((void **)&h, &hlen) < 0)
-      return -1;
-    if (h->serial != 11)
-      return -1;
-    cvio = cache_vc->do_io_read(this, nbytes, buffer);
-    return 1;
-  });
+  CACHE_SM(
+    t, replace_read_test, { cacheProcessor.open_read(this, &key); } int open_read_callout() override {
+      CacheTestHeader *h = nullptr;
+      int hlen           = 0;
+      if (cache_vc->get_header((void **)&h, &hlen) < 0)
+        return -1;
+      if (h->serial != 11)
+        return -1;
+      cvio = cache_vc->do_io_read(this, nbytes, buffer);
+      return 1;
+    });
   replace_read_test.expect_initial_event = CACHE_EVENT_OPEN_READ;
   replace_read_test.expect_event         = VC_EVENT_READ_COMPLETE;
   replace_read_test.nbytes               = 100;
   replace_read_test.key                  = replace_test.key;
   replace_read_test.content_salt         = 1;
 
-  CACHE_SM(t, large_write_test, { cacheProcessor.open_write(this, &key, false, CACHE_FRAG_TYPE_NONE, 100, CACHE_WRITE_OPT_SYNC); });
+  CACHE_SM(t, large_write_test, { cacheProcessor.open_write(this, &key, CACHE_FRAG_TYPE_NONE, 100, CACHE_WRITE_OPT_SYNC); });
   large_write_test.expect_initial_event = CACHE_EVENT_OPEN_WRITE;
   large_write_test.expect_event         = VC_EVENT_WRITE_COMPLETE;
   large_write_test.nbytes               = 10000000;
   rand_CacheKey(&large_write_test.key, thread->mutex);
 
-  CACHE_SM(t, pread_test, { cacheProcessor.open_read(this, &key, false); } int open_read_callout() {
-    cvio = cache_vc->do_io_pread(this, nbytes, buffer, 7000000);
-    return 1;
-  });
+  CACHE_SM(
+    t, pread_test, { cacheProcessor.open_read(this, &key); } int open_read_callout() override {
+      cvio = cache_vc->do_io_pread(this, nbytes, buffer, 7000000);
+      return 1;
+    });
   pread_test.expect_initial_event = CACHE_EVENT_OPEN_READ;
   pread_test.expect_event         = VC_EVENT_READ_COMPLETE;
   pread_test.nbytes               = 100;
@@ -456,7 +454,7 @@ REGRESSION_TEST(cache_disk_replacement_stability)(RegressionTest *t, int level,
     vols[i].disk = &disk;
     vols[i].len  = DEFAULT_STRIPE_SIZE;
     snprintf(buff, sizeof(buff), "/dev/sd%c %" PRIu64 ":%" PRIu64, 'a' + i, DEFAULT_SKIP, vols[i].len);
-    MD5Context().hash_immediate(vols[i].hash_id, buff, strlen(buff));
+    CryptoContext().hash_immediate(vols[i].hash_id, buff, strlen(buff));
   }
 
   hr1.vol_hash_table = nullptr;
@@ -471,26 +469,30 @@ REGRESSION_TEST(cache_disk_replacement_stability)(RegressionTest *t, int level,
   sample      = vols + sample_idx;
   sample->len = 1024ULL * 1024 * 1024 * (1024 + 128); // 1.1 TB
   snprintf(buff, sizeof(buff), "/dev/sd%c %" PRIu64 ":%" PRIu64, 'a' + sample_idx, DEFAULT_SKIP, sample->len);
-  MD5Context().hash_immediate(sample->hash_id, buff, strlen(buff));
+  CryptoContext().hash_immediate(sample->hash_id, buff, strlen(buff));
   build_vol_hash_table(&hr2);
 
   // See what the difference is
   int to = 0, from = 0;
   int then = 0, now = 0;
   for (int i = 0; i < VOL_HASH_TABLE_SIZE; ++i) {
-    if (hr1.vol_hash_table[i] == sample_idx)
+    if (hr1.vol_hash_table[i] == sample_idx) {
       ++then;
-    if (hr2.vol_hash_table[i] == sample_idx)
+    }
+    if (hr2.vol_hash_table[i] == sample_idx) {
       ++now;
+    }
     if (hr1.vol_hash_table[i] != hr2.vol_hash_table[i]) {
-      if (hr1.vol_hash_table[i] == sample_idx)
+      if (hr1.vol_hash_table[i] == sample_idx) {
         ++from;
-      else
+      } else {
         ++to;
+      }
     }
   }
-  rprintf(t, "Cache stability difference - "
-             "delta = %d of %d : %d to, %d from, originally %d slots, now %d slots (net gain = %d/%d)\n",
+  rprintf(t,
+          "Cache stability difference - "
+          "delta = %d of %d : %d to, %d from, originally %d slots, now %d slots (net gain = %d/%d)\n",
           to + from, VOL_HASH_TABLE_SIZE, to, from, then, now, now - then, to - from);
   *pstatus = REGRESSION_TEST_PASSED;
 
@@ -508,16 +510,20 @@ static double *zipf_table = nullptr;
 static void
 build_zipf()
 {
-  if (zipf_table)
+  if (zipf_table) {
     return;
-  zipf_table = (double *)ats_malloc(ZIPF_SIZE * sizeof(double));
-  for (int i      = 0; i < ZIPF_SIZE; i++)
+  }
+  zipf_table = static_cast<double *>(ats_malloc(ZIPF_SIZE * sizeof(double)));
+  for (int i = 0; i < ZIPF_SIZE; i++) {
     zipf_table[i] = 1.0 / pow(i + 2, zipf_alpha);
-  for (int i      = 1; i < ZIPF_SIZE; i++)
+  }
+  for (int i = 1; i < ZIPF_SIZE; i++) {
     zipf_table[i] = zipf_table[i - 1] + zipf_table[i];
-  double x        = zipf_table[ZIPF_SIZE - 1];
-  for (int i      = 0; i < ZIPF_SIZE; i++)
+  }
+  double x = zipf_table[ZIPF_SIZE - 1];
+  for (int i = 0; i < ZIPF_SIZE; i++) {
     zipf_table[i] = zipf_table[i] / x;
+  }
 }
 
 static int
@@ -526,13 +532,15 @@ get_zipf(double v)
   int l = 0, r = ZIPF_SIZE - 1, m;
   do {
     m = (r + l) / 2;
-    if (v < zipf_table[m])
+    if (v < zipf_table[m]) {
       r = m - 1;
-    else
+    } else {
       l = m + 1;
+    }
   } while (l < r);
-  if (zipf_bucket_size == 1)
+  if (zipf_bucket_size == 1) {
     return m;
+  }
   double x = zipf_table[m], y = zipf_table[m + 1];
   m += static_cast<int>((v - x) / (y - x));
   return m;
@@ -551,32 +559,32 @@ test_RamCache(RegressionTest *t, RamCache *cache, const char *name, int64_t cach
   for (int l = 0; l < 10; l++) {
     for (int i = 0; i < 200; i++) {
       IOBufferData *d = THREAD_ALLOC(ioDataAllocator, this_thread());
-      INK_MD5 md5;
+      CryptoHash hash;
 
       d->alloc(BUFFER_SIZE_INDEX_16K);
       data.push_back(make_ptr(d));
-      md5.u64[0] = ((uint64_t)i << 32) + i;
-      md5.u64[1] = ((uint64_t)i << 32) + i;
-      cache->put(&md5, data[i].get(), 1 << 15);
+      hash.u64[0] = (static_cast<uint64_t>(i) << 32) + i;
+      hash.u64[1] = (static_cast<uint64_t>(i) << 32) + i;
+      cache->put(&hash, data[i].get(), 1 << 15);
       // More hits for the first 10.
       for (int j = 0; j <= i && j < 10; j++) {
         Ptr<IOBufferData> data;
-        INK_MD5 md5;
+        CryptoHash hash;
 
-        md5.u64[0] = ((uint64_t)j << 32) + j;
-        md5.u64[1] = ((uint64_t)j << 32) + j;
-        cache->get(&md5, &data);
+        hash.u64[0] = (static_cast<uint64_t>(j) << 32) + j;
+        hash.u64[1] = (static_cast<uint64_t>(j) << 32) + j;
+        cache->get(&hash, &data);
       }
     }
   }
 
   for (int i = 0; i < 10; i++) {
-    INK_MD5 md5;
+    CryptoHash hash;
     Ptr<IOBufferData> data;
 
-    md5.u64[0] = ((uint64_t)i << 32) + i;
-    md5.u64[1] = ((uint64_t)i << 32) + i;
-    if (!cache->get(&md5, &data)) {
+    hash.u64[0] = (static_cast<uint64_t>(i) << 32) + i;
+    hash.u64[1] = (static_cast<uint64_t>(i) << 32) + i;
+    if (!cache->get(&hash, &data)) {
       pass = false;
     }
   }
@@ -584,54 +592,59 @@ test_RamCache(RegressionTest *t, RamCache *cache, const char *name, int64_t cach
   int sample_size = cache_size >> 6;
   build_zipf();
   srand48(13);
-  int *r = (int *)ats_malloc(sample_size * sizeof(int));
-  for (int i = 0; i < sample_size; i++)
+  int *r = static_cast<int *>(ats_malloc(sample_size * sizeof(int)));
+  for (int i = 0; i < sample_size; i++) {
     // coverity[dont_call]
     r[i] = get_zipf(drand48());
+  }
   data.clear();
   int misses = 0;
   for (int i = 0; i < sample_size; i++) {
-    INK_MD5 md5;
-    md5.u64[0] = ((uint64_t)r[i] << 32) + r[i];
-    md5.u64[1] = ((uint64_t)r[i] << 32) + r[i];
+    CryptoHash hash;
+    hash.u64[0] = (static_cast<uint64_t>(r[i]) << 32) + r[i];
+    hash.u64[1] = (static_cast<uint64_t>(r[i]) << 32) + r[i];
     Ptr<IOBufferData> get_data;
-    if (!cache->get(&md5, &get_data)) {
+    if (!cache->get(&hash, &get_data)) {
       IOBufferData *d = THREAD_ALLOC(ioDataAllocator, this_thread());
       d->alloc(BUFFER_SIZE_INDEX_16K);
       data.push_back(make_ptr(d));
-      cache->put(&md5, data.back().get(), 1 << 15);
-      if (i >= sample_size / 2)
+      cache->put(&hash, data.back().get(), 1 << 15);
+      if (i >= sample_size / 2) {
         misses++; // Sample last half of the gets.
+      }
     }
   }
-  double fixed_hit_rate = 1.0 - (((double)(misses)) / (sample_size / 2));
+  double fixed_hit_rate = 1.0 - ((static_cast<double>(misses)) / (sample_size / 2));
   rprintf(t, "RamCache %s Fixed Size Hit Rate %f\n", name, fixed_hit_rate);
 
   data.clear();
   misses = 0;
   for (int i = 0; i < sample_size; i++) {
-    INK_MD5 md5;
-    md5.u64[0] = ((uint64_t)r[i] << 32) + r[i];
-    md5.u64[1] = ((uint64_t)r[i] << 32) + r[i];
+    CryptoHash hash;
+    hash.u64[0] = (static_cast<uint64_t>(r[i]) << 32) + r[i];
+    hash.u64[1] = (static_cast<uint64_t>(r[i]) << 32) + r[i];
     Ptr<IOBufferData> get_data;
-    if (!cache->get(&md5, &get_data)) {
+    if (!cache->get(&hash, &get_data)) {
       IOBufferData *d = THREAD_ALLOC(ioDataAllocator, this_thread());
       d->alloc(BUFFER_SIZE_INDEX_8K + (r[i] % 3));
       data.push_back(make_ptr(d));
-      cache->put(&md5, data.back().get(), d->block_size());
-      if (i >= sample_size / 2)
+      cache->put(&hash, data.back().get(), d->block_size());
+      if (i >= sample_size / 2) {
         misses++; // Sample last half of the gets.
+      }
     }
   }
-  double variable_hit_rate = 1.0 - (((double)(misses)) / (sample_size / 2));
+  double variable_hit_rate = 1.0 - ((static_cast<double>(misses)) / (sample_size / 2));
   rprintf(t, "RamCache %s Variable Size Hit Rate %f\n", name, variable_hit_rate);
 
   rprintf(t, "RamCache %s Nominal Size %lld Size %lld\n", name, cache_size, cache->size());
 
-  if (fixed_hit_rate < 0.55 || variable_hit_rate < 0.55)
+  if (fixed_hit_rate < 0.55 || variable_hit_rate < 0.55) {
     return false;
-  if (abs(cache_size - cache->size()) > 0.02 * cache_size)
+  }
+  if (abs(cache_size - cache->size()) > 0.02 * cache_size) {
     return false;
+  }
 
   ats_free(r);
 
@@ -642,8 +655,7 @@ test_RamCache(RegressionTest *t, RamCache *cache, const char *name, int64_t cach
 
 REGRESSION_TEST(ram_cache)(RegressionTest *t, int level, int *pstatus)
 {
-  // Run with -R 3 for now to trigger this check, until we figure out the CI
-  if (REGRESSION_TEST_EXTENDED > level) {
+  if (REGRESSION_TEST_NIGHTLY > level) {
     *pstatus = REGRESSION_TEST_PASSED;
     return;
   }
@@ -653,10 +665,16 @@ REGRESSION_TEST(ram_cache)(RegressionTest *t, int level, int *pstatus)
     *pstatus = REGRESSION_TEST_FAILED;
     return;
   }
-  for (int s = 20; s <= 28; s += 4) {
+
+  // Test cache sizes from 1MB to 16MB. The sample_size is cache_size >> 6, so
+  // the 16MB test runs 262K iterations which completes in reasonable time. This
+  // used to run with 256MB (s=28) at 4M+ iterations, which is too much for CI
+  // resulting in failures, either due to timeout or OOM issues.
+  for (int s = 20; s <= 24; s += 4) {
     int64_t cache_size = 1LL << s;
     *pstatus           = REGRESSION_TEST_PASSED;
-    if (!test_RamCache(t, new_RamCacheLRU(), "LRU", cache_size) || !test_RamCache(t, new_RamCacheCLFUS(), "CLFUS", cache_size))
+    if (!test_RamCache(t, new_RamCacheLRU(), "LRU", cache_size) || !test_RamCache(t, new_RamCacheCLFUS(), "CLFUS", cache_size)) {
       *pstatus = REGRESSION_TEST_FAILED;
+    }
   }
 }
