@@ -28,8 +28,7 @@
  *
  ****************************************************************************/
 
-#ifndef _I_SPLIT_DNSProcessor_H_
-#define _I_SPLIT_DNSProcessor_H_
+#pragma once
 
 struct SplitDNS;
 
@@ -37,7 +36,6 @@ struct SplitDNS;
    **                struct SplitDNSConfig
    -------------------------------------------------------------- */
 
-
 struct SplitDNSConfig {
   static void startup();
 
@@ -50,8 +48,7 @@ struct SplitDNSConfig {
 
   static int m_id;
   static Ptr<ProxyMutex> dnsHandler_mutex;
+  static ConfigUpdateHandler<SplitDNSConfig> *splitDNSUpdate;
 
   static int gsplit_dns_enabled;
 };
-
-#endif
