@@ -22,19 +22,17 @@
 
  */
 
-#if !defined (I_Tasks_h)
-#define I_Tasks_h
+#pragma once
 
 #include "I_EventSystem.h"
 
 extern EventType ET_TASK;
 
-class TasksProcessor: public Processor
+class TasksProcessor : public Processor
 {
- public: 
-  int start(int task_threads, size_t stacksize=DEFAULT_STACKSIZE);
+public:
+  EventType register_event_type();
+  int start(int task_threads, size_t stacksize = DEFAULT_STACKSIZE) override;
 };
 
 extern TasksProcessor tasksProcessor;
-
-#endif
