@@ -21,11 +21,10 @@
   limitations under the License.
  */
 
-#if !defined(_P_IOBuffer_h)
-#define _P_IOBuffer_h
+#pragma once
 
-#include "ts/ink_platform.h"
-#include "ts/ink_resource.h"
+#include "tscore/ink_platform.h"
+#include "tscore/ink_resource.h"
 
 // TODO: I think we're overly aggressive here on making MIOBuffer 64-bit
 // but not sure it's worthwhile changing anything to 32-bit honestly.
@@ -37,33 +36,36 @@
 //
 //////////////////////////////////////////////////////////////
 TS_INLINE int64_t
-buffer_size_to_index(int64_t size, int64_t max = max_iobuffer_size)
+buffer_size_to_index(int64_t size, int64_t max)
 {
   int64_t r = max;
 
-  while (r && BUFFER_SIZE_FOR_INDEX(r - 1) >= size)
+  while (r && BUFFER_SIZE_FOR_INDEX(r - 1) >= size) {
     r--;
+  }
   return r;
 }
 
 TS_INLINE int64_t
 iobuffer_size_to_index(int64_t size, int64_t max)
 {
-  if (size > BUFFER_SIZE_FOR_INDEX(max))
+  if (size > BUFFER_SIZE_FOR_INDEX(max)) {
     return BUFFER_SIZE_INDEX_FOR_XMALLOC_SIZE(size);
+  }
   return buffer_size_to_index(size, max);
 }
 
 TS_INLINE int64_t
 index_to_buffer_size(int64_t idx)
 {
-  if (BUFFER_SIZE_INDEX_IS_FAST_ALLOCATED(idx))
+  if (BUFFER_SIZE_INDEX_IS_FAST_ALLOCATED(idx)) {
     return BUFFER_SIZE_FOR_INDEX(idx);
-  else if (BUFFER_SIZE_INDEX_IS_XMALLOCED(idx))
+  } else if (BUFFER_SIZE_INDEX_IS_XMALLOCED(idx)) {
     return BUFFER_SIZE_FOR_XMALLOC(idx);
-  // coverity[dead_error_condition]
-  else if (BUFFER_SIZE_INDEX_IS_CONSTANT(idx))
+    // coverity[dead_error_condition]
+  } else if (BUFFER_SIZE_INDEX_IS_CONSTANT(idx)) {
     return BUFFER_SIZE_FOR_CONSTANT(idx);
+  }
   // coverity[dead_error_line]
   return 0;
 }
@@ -71,8 +73,8 @@ index_to_buffer_size(int64_t idx)
 TS_INLINE IOBufferBlock *
 iobufferblock_clone(IOBufferBlock *src, int64_t offset, int64_t len)
 {
-  IOBufferBlock *start_buf   = NULL;
-  IOBufferBlock *current_buf = NULL;
+  IOBufferBlock *start_buf   = nullptr;
+  IOBufferBlock *current_buf = nullptr;
 
   while (src && len >= 0) {
     char *start       = src->_start;
@@ -144,34 +146,38 @@ iobufferblock_skip(IOBufferBlock *b, int64_t *poffset, int64_t *plen, int64_t wr
   return b;
 }
 
-#ifdef TRACK_BUFFER_USER
 TS_INLINE void
 iobuffer_mem_inc(const char *_loc, int64_t _size_index)
 {
-  if (!res_track_memory)
+  if (!res_track_memory) {
     return;
+  }
 
-  if (!BUFFER_SIZE_INDEX_IS_FAST_ALLOCATED(_size_index))
+  if (!BUFFER_SIZE_INDEX_IS_FAST_ALLOCATED(_size_index)) {
     return;
+  }
 
-  if (!_loc)
+  if (!_loc) {
     _loc = "memory/IOBuffer/UNKNOWN-LOCATION";
+  }
   ResourceTracker::increment(_loc, index_to_buffer_size(_size_index));
 }
 
 TS_INLINE void
 iobuffer_mem_dec(const char *_loc, int64_t _size_index)
 {
-  if (!res_track_memory)
+  if (!res_track_memory) {
     return;
+  }
 
-  if (!BUFFER_SIZE_INDEX_IS_FAST_ALLOCATED(_size_index))
+  if (!BUFFER_SIZE_INDEX_IS_FAST_ALLOCATED(_size_index)) {
     return;
-  if (!_loc)
+  }
+  if (!_loc) {
     _loc = "memory/IOBuffer/UNKNOWN-LOCATION";
+  }
   ResourceTracker::increment(_loc, -index_to_buffer_size(_size_index));
 }
-#endif
 
 //////////////////////////////////////////////////////////////////
 //
@@ -191,76 +197,28 @@ IOBufferData::block_size()
 }
 
 TS_INLINE IOBufferData *
-new_IOBufferData_internal(
-#ifdef TRACK_BUFFER_USER
-  const char *location,
-#endif
-  void *b, int64_t size, int64_t asize_index)
+new_IOBufferData_internal(const char *location, void *b, int64_t size, int64_t asize_index)
 {
   (void)size;
   IOBufferData *d = THREAD_ALLOC(ioDataAllocator, this_thread());
   d->_size_index  = asize_index;
   ink_assert(BUFFER_SIZE_INDEX_IS_CONSTANT(asize_index) || size <= d->block_size());
-#ifdef TRACK_BUFFER_USER
   d->_location = location;
-#endif
-  d->_data = (char *)b;
+  d->_data     = (char *)b;
   return d;
 }
 
 TS_INLINE IOBufferData *
-new_constant_IOBufferData_internal(
-#ifdef TRACK_BUFFER_USER
-  const char *loc,
-#endif
-  void *b, int64_t size)
+new_xmalloc_IOBufferData_internal(const char *location, void *b, int64_t size)
 {
-  return new_IOBufferData_internal(
-#ifdef TRACK_BUFFER_USER
-    loc,
-#endif
-    b, size, BUFFER_SIZE_INDEX_FOR_CONSTANT_SIZE(size));
+  return new_IOBufferData_internal(location, b, size, BUFFER_SIZE_INDEX_FOR_XMALLOC_SIZE(size));
 }
 
 TS_INLINE IOBufferData *
-new_xmalloc_IOBufferData_internal(
-#ifdef TRACK_BUFFER_USER
-  const char *location,
-#endif
-  void *b, int64_t size)
-{
-  return new_IOBufferData_internal(
-#ifdef TRACK_BUFFER_USER
-    location,
-#endif
-    b, size, BUFFER_SIZE_INDEX_FOR_XMALLOC_SIZE(size));
-}
-
-TS_INLINE IOBufferData *
-new_IOBufferData_internal(
-#ifdef TRACK_BUFFER_USER
-  const char *location,
-#endif
-  void *b, int64_t size)
-{
-  return new_IOBufferData_internal(
-#ifdef TRACK_BUFFER_USER
-    location,
-#endif
-    b, size, iobuffer_size_to_index(size));
-}
-
-TS_INLINE IOBufferData *
-new_IOBufferData_internal(
-#ifdef TRACK_BUFFER_USER
-  const char *loc,
-#endif
-  int64_t size_index, AllocType type)
+new_IOBufferData_internal(const char *loc, int64_t size_index, AllocType type)
 {
   IOBufferData *d = THREAD_ALLOC(ioDataAllocator, this_thread());
-#ifdef TRACK_BUFFER_USER
-  d->_location = loc;
-#endif
+  d->_location    = loc;
   d->alloc(size_index, type);
   return d;
 }
@@ -272,27 +230,28 @@ new_IOBufferData_internal(
 TS_INLINE void
 IOBufferData::alloc(int64_t size_index, AllocType type)
 {
-  if (_data)
+  if (_data) {
     dealloc();
+  }
   _size_index = size_index;
   _mem_type   = type;
-#ifdef TRACK_BUFFER_USER
   iobuffer_mem_inc(_location, size_index);
-#endif
   switch (type) {
   case MEMALIGNED:
-    if (BUFFER_SIZE_INDEX_IS_FAST_ALLOCATED(size_index))
+    if (BUFFER_SIZE_INDEX_IS_FAST_ALLOCATED(size_index)) {
       _data = (char *)ioBufAllocator[size_index].alloc_void();
-    // coverity[dead_error_condition]
-    else if (BUFFER_SIZE_INDEX_IS_XMALLOCED(size_index))
+      // coverity[dead_error_condition]
+    } else if (BUFFER_SIZE_INDEX_IS_XMALLOCED(size_index)) {
       _data = (char *)ats_memalign(ats_pagesize(), index_to_buffer_size(size_index));
+    }
     break;
   default:
   case DEFAULT_ALLOC:
-    if (BUFFER_SIZE_INDEX_IS_FAST_ALLOCATED(size_index))
+    if (BUFFER_SIZE_INDEX_IS_FAST_ALLOCATED(size_index)) {
       _data = (char *)ioBufAllocator[size_index].alloc_void();
-    else if (BUFFER_SIZE_INDEX_IS_XMALLOCED(size_index))
+    } else if (BUFFER_SIZE_INDEX_IS_XMALLOCED(size_index)) {
       _data = (char *)ats_malloc(BUFFER_SIZE_FOR_XMALLOC(size_index));
+    }
     break;
   }
 }
@@ -302,25 +261,25 @@ IOBufferData::alloc(int64_t size_index, AllocType type)
 TS_INLINE void
 IOBufferData::dealloc()
 {
-#ifdef TRACK_BUFFER_USER
   iobuffer_mem_dec(_location, _size_index);
-#endif
   switch (_mem_type) {
   case MEMALIGNED:
-    if (BUFFER_SIZE_INDEX_IS_FAST_ALLOCATED(_size_index))
+    if (BUFFER_SIZE_INDEX_IS_FAST_ALLOCATED(_size_index)) {
       ioBufAllocator[_size_index].free_void(_data);
-    else if (BUFFER_SIZE_INDEX_IS_XMALLOCED(_size_index))
+    } else if (BUFFER_SIZE_INDEX_IS_XMALLOCED(_size_index)) {
       ::free((void *)_data);
+    }
     break;
   default:
   case DEFAULT_ALLOC:
-    if (BUFFER_SIZE_INDEX_IS_FAST_ALLOCATED(_size_index))
+    if (BUFFER_SIZE_INDEX_IS_FAST_ALLOCATED(_size_index)) {
       ioBufAllocator[_size_index].free_void(_data);
-    else if (BUFFER_SIZE_INDEX_IS_XMALLOCED(_size_index))
+    } else if (BUFFER_SIZE_INDEX_IS_XMALLOCED(_size_index)) {
       ats_free(_data);
+    }
     break;
   }
-  _data       = 0;
+  _data       = nullptr;
   _size_index = BUFFER_SIZE_NOT_ALLOCATED;
   _mem_type   = NO_ALLOC;
 }
@@ -339,43 +298,24 @@ IOBufferData::free()
 //
 //////////////////////////////////////////////////////////////////
 TS_INLINE IOBufferBlock *
-new_IOBufferBlock_internal(
-#ifdef TRACK_BUFFER_USER
-  const char *location
-#endif
-  )
+new_IOBufferBlock_internal(const char *location)
 {
   IOBufferBlock *b = THREAD_ALLOC(ioBlockAllocator, this_thread());
-#ifdef TRACK_BUFFER_USER
-  b->_location = location;
-#endif
+  b->_location     = location;
   return b;
 }
 
 TS_INLINE IOBufferBlock *
-new_IOBufferBlock_internal(
-#ifdef TRACK_BUFFER_USER
-  const char *location,
-#endif
-  IOBufferData *d, int64_t len, int64_t offset)
+new_IOBufferBlock_internal(const char *location, IOBufferData *d, int64_t len, int64_t offset)
 {
   IOBufferBlock *b = THREAD_ALLOC(ioBlockAllocator, this_thread());
-#ifdef TRACK_BUFFER_USER
-  b->_location = location;
-#endif
+  b->_location     = location;
   b->set(d, len, offset);
   return b;
 }
 
 TS_INLINE
 IOBufferBlock::IOBufferBlock()
-  : _start(0),
-    _end(0),
-    _buf_end(0)
-#ifdef TRACK_BUFFER_USER
-    ,
-    _location(0)
-#endif
 {
   return;
 }
@@ -405,18 +345,14 @@ TS_INLINE void
 IOBufferBlock::alloc(int64_t i)
 {
   ink_assert(BUFFER_SIZE_ALLOCATED(i));
-#ifdef TRACK_BUFFER_USER
   data = new_IOBufferData_internal(_location, i);
-#else
-  data             = new_IOBufferData_internal(i);
-#endif
   reset();
 }
 
 TS_INLINE void
 IOBufferBlock::clear()
 {
-  data = NULL;
+  data = nullptr;
 
   IOBufferBlock *p = next.get();
   while (p) {
@@ -436,24 +372,18 @@ IOBufferBlock::clear()
   // because we already manually did that.
   next.detach();
 
-  _buf_end = _end = _start = NULL;
+  _buf_end = _end = _start = nullptr;
 }
 
 TS_INLINE IOBufferBlock *
-IOBufferBlock::clone()
+IOBufferBlock::clone() const
 {
-#ifdef TRACK_BUFFER_USER
   IOBufferBlock *b = new_IOBufferBlock_internal(_location);
-#else
-  IOBufferBlock *b = new_IOBufferBlock_internal();
-#endif
-  b->data     = data;
-  b->_start   = _start;
-  b->_end     = _end;
-  b->_buf_end = _end;
-#ifdef TRACK_BUFFER_USER
-  b->_location = _location;
-#endif
+  b->data          = data;
+  b->_start        = _start;
+  b->_end          = _end;
+  b->_buf_end      = _end;
+  b->_location     = _location;
   return b;
 }
 
@@ -473,15 +403,9 @@ IOBufferBlock::free()
 TS_INLINE void
 IOBufferBlock::set_internal(void *b, int64_t len, int64_t asize_index)
 {
-#ifdef TRACK_BUFFER_USER
-  data = new_IOBufferData_internal(_location, BUFFER_SIZE_NOT_ALLOCATED);
-#else
-  data             = new_IOBufferData_internal(BUFFER_SIZE_NOT_ALLOCATED);
-#endif
+  data        = new_IOBufferData_internal(_location, BUFFER_SIZE_NOT_ALLOCATED);
   data->_data = (char *)b;
-#ifdef TRACK_BUFFER_USER
   iobuffer_mem_inc(_location, asize_index);
-#endif
   data->_size_index = asize_index;
   reset();
   _end = _start + len;
@@ -496,46 +420,6 @@ IOBufferBlock::set(IOBufferData *d, int64_t len, int64_t offset)
   _buf_end = buf() + d->block_size();
 }
 
-TS_INLINE void
-IOBufferBlock::realloc_set_internal(void *b, int64_t buf_size, int64_t asize_index)
-{
-  int64_t data_size = size();
-  memcpy(b, _start, size());
-  dealloc();
-  set_internal(b, buf_size, asize_index);
-  _end = _start + data_size;
-}
-
-TS_INLINE void
-IOBufferBlock::realloc(void *b, int64_t buf_size)
-{
-  realloc_set_internal(b, buf_size, BUFFER_SIZE_NOT_ALLOCATED);
-}
-
-TS_INLINE void
-IOBufferBlock::realloc_xmalloc(void *b, int64_t buf_size)
-{
-  realloc_set_internal(b, buf_size, -buf_size);
-}
-
-TS_INLINE void
-IOBufferBlock::realloc_xmalloc(int64_t buf_size)
-{
-  realloc_set_internal(ats_malloc(buf_size), buf_size, -buf_size);
-}
-
-TS_INLINE void
-IOBufferBlock::realloc(int64_t i)
-{
-  if ((i == data->_size_index) || (i >= (int64_t)countof(ioBufAllocator))) {
-    return;
-  }
-
-  ink_release_assert(i > data->_size_index && i != BUFFER_SIZE_NOT_ALLOCATED);
-  void *b = ioBufAllocator[i].alloc_void();
-  realloc_set_internal(b, BUFFER_SIZE_FOR_INDEX(i), i);
-}
-
 //////////////////////////////////////////////////////////////////
 //
 //  class IOBufferReader --
@@ -579,7 +463,7 @@ TS_INLINE char *
 IOBufferReader::start()
 {
   if (!block) {
-    return 0;
+    return nullptr;
   }
 
   skip_empty_blocks();
@@ -590,7 +474,7 @@ TS_INLINE char *
 IOBufferReader::end()
 {
   if (!block) {
-    return 0;
+    return nullptr;
   }
 
   skip_empty_blocks();
@@ -608,6 +492,13 @@ IOBufferReader::block_read_avail()
   return (int64_t)(block->end() - (block->start() + start_offset));
 }
 
+inline std::string_view
+IOBufferReader::block_read_view()
+{
+  const char *start = this->start(); // empty blocks are skipped in here.
+  return start ? std::string_view{start, static_cast<size_t>(block->end() - start)} : std::string_view{};
+}
+
 TS_INLINE int
 IOBufferReader::block_count()
 {
@@ -641,7 +532,7 @@ IOBufferReader::read_avail()
   return t;
 }
 
-inline bool
+TS_INLINE bool
 IOBufferReader::is_read_avail_more_than(int64_t size)
 {
   int64_t t        = -start_offset;
@@ -660,6 +551,7 @@ IOBufferReader::is_read_avail_more_than(int64_t size)
 TS_INLINE void
 IOBufferReader::consume(int64_t n)
 {
+  ink_assert(read_avail() >= n);
   start_offset += n;
   if (size_limit != INT64_MAX) {
     size_limit -= n;
@@ -678,38 +570,35 @@ IOBufferReader::consume(int64_t n)
     block        = block->next;
     r            = block->read_avail();
   }
-
-  ink_assert(read_avail() >= 0);
 }
 
-TS_INLINE char &IOBufferReader::operator[](int64_t i)
+TS_INLINE char &
+IOBufferReader::operator[](int64_t i)
 {
-  static char _error = '\0';
-  IOBufferBlock *b   = block.get();
+  static char default_ret = '\0'; // This is just to avoid compiler warnings...
+  IOBufferBlock *b        = block.get();
 
   i += start_offset;
   while (b) {
     int64_t bytes = b->read_avail();
-    if (bytes > i)
+    if (bytes > i) {
       return b->start()[i];
+    }
     i -= bytes;
     b = b->next.get();
   }
 
-  ink_assert(!"out of range");
-  if (unlikely(b)) {
-    return *b->start();
-  }
-
-  return _error;
+  ink_release_assert(!"out of range");
+  // Never used, just to satisfy compilers not understanding the fatality of ink_release_assert().
+  return default_ret;
 }
 
 TS_INLINE void
 IOBufferReader::clear()
 {
-  accessor     = NULL;
-  block        = NULL;
-  mbuf         = NULL;
+  accessor     = nullptr;
+  block        = nullptr;
+  mbuf         = nullptr;
   start_offset = 0;
   size_limit   = INT64_MAX;
 }
@@ -728,7 +617,7 @@ IOBufferReader::reset()
 //      inline functions definitions
 //
 ////////////////////////////////////////////////////////////////
-inkcoreapi extern ClassAllocator<MIOBuffer> ioAllocator;
+extern ClassAllocator<MIOBuffer> ioAllocator;
 ////////////////////////////////////////////////////////////////
 //
 //  MIOBuffer::MIOBuffer()
@@ -745,9 +634,7 @@ inkcoreapi extern ClassAllocator<MIOBuffer> ioAllocator;
 TS_INLINE
 MIOBuffer::MIOBuffer(void *b, int64_t bufsize, int64_t aWater_mark)
 {
-#ifdef TRACK_BUFFER_USER
-  _location = NULL;
-#endif
+  _location = nullptr;
   set(b, bufsize);
   water_mark = aWater_mark;
   size_index = BUFFER_SIZE_NOT_ALLOCATED;
@@ -759,9 +646,7 @@ MIOBuffer::MIOBuffer(int64_t default_size_index)
 {
   clear();
   size_index = default_size_index;
-#ifdef TRACK_BUFFER_USER
-  _location = NULL;
-#endif
+  _location  = nullptr;
   return;
 }
 
@@ -769,54 +654,42 @@ TS_INLINE
 MIOBuffer::MIOBuffer()
 {
   clear();
-#ifdef TRACK_BUFFER_USER
-  _location = NULL;
-#endif
+  _location = nullptr;
   return;
 }
 
 TS_INLINE
 MIOBuffer::~MIOBuffer()
 {
-  _writer = NULL;
+  _writer = nullptr;
   dealloc_all_readers();
 }
 
 TS_INLINE MIOBuffer *
-new_MIOBuffer_internal(
-#ifdef TRACK_BUFFER_USER
-  const char *location,
-#endif
-  int64_t size_index)
+new_MIOBuffer_internal(const char *location, int64_t size_index)
 {
   MIOBuffer *b = THREAD_ALLOC(ioAllocator, this_thread());
-#ifdef TRACK_BUFFER_USER
   b->_location = location;
-#endif
   b->alloc(size_index);
+  b->water_mark = 0;
   return b;
 }
 
 TS_INLINE void
 free_MIOBuffer(MIOBuffer *mio)
 {
-  mio->_writer = NULL;
+  mio->_writer = nullptr;
   mio->dealloc_all_readers();
   THREAD_FREE(mio, ioAllocator, this_thread());
 }
 
 TS_INLINE MIOBuffer *
-new_empty_MIOBuffer_internal(
-#ifdef TRACK_BUFFER_USER
-  const char *location,
-#endif
-  int64_t size_index)
+new_empty_MIOBuffer_internal(const char *location, int64_t size_index)
 {
   MIOBuffer *b  = THREAD_ALLOC(ioAllocator, this_thread());
   b->size_index = size_index;
-#ifdef TRACK_BUFFER_USER
-  b->_location = location;
-#endif
+  b->water_mark = 0;
+  b->_location  = location;
   return b;
 }
 
@@ -830,11 +703,13 @@ TS_INLINE IOBufferReader *
 MIOBuffer::alloc_accessor(MIOBufferAccessor *anAccessor)
 {
   int i;
-  for (i = 0; i < MAX_MIOBUFFER_READERS; i++)
-    if (!readers[i].allocated())
+  for (i = 0; i < MAX_MIOBUFFER_READERS; i++) {
+    if (!readers[i].allocated()) {
       break;
+    }
+  }
 
-  // TODO refactor code to return NULL at some point
+  // TODO refactor code to return nullptr at some point
   ink_release_assert(i < MAX_MIOBUFFER_READERS);
 
   IOBufferReader *e = &readers[i];
@@ -849,17 +724,19 @@ TS_INLINE IOBufferReader *
 MIOBuffer::alloc_reader()
 {
   int i;
-  for (i = 0; i < MAX_MIOBUFFER_READERS; i++)
-    if (!readers[i].allocated())
+  for (i = 0; i < MAX_MIOBUFFER_READERS; i++) {
+    if (!readers[i].allocated()) {
       break;
+    }
+  }
 
-  // TODO refactor code to return NULL at some point
+  // TODO refactor code to return nullptr at some point
   ink_release_assert(i < MAX_MIOBUFFER_READERS);
 
   IOBufferReader *e = &readers[i];
   e->mbuf           = this;
   e->reset();
-  e->accessor = NULL;
+  e->accessor = nullptr;
 
   return e;
 }
@@ -873,16 +750,18 @@ TS_INLINE IOBufferReader *
 MIOBuffer::clone_reader(IOBufferReader *r)
 {
   int i;
-  for (i = 0; i < MAX_MIOBUFFER_READERS; i++)
-    if (!readers[i].allocated())
+  for (i = 0; i < MAX_MIOBUFFER_READERS; i++) {
+    if (!readers[i].allocated()) {
       break;
+    }
+  }
 
-  // TODO refactor code to return NULL at some point
+  // TODO refactor code to return nullptr at some point
   ink_release_assert(i < MAX_MIOBUFFER_READERS);
 
   IOBufferReader *e = &readers[i];
   e->mbuf           = this;
-  e->accessor       = NULL;
+  e->accessor       = nullptr;
   e->block          = r->block;
   e->start_offset   = r->start_offset;
   e->size_limit     = r->size_limit;
@@ -918,7 +797,6 @@ MIOBuffer::append_block_internal(IOBufferBlock *b)
 {
   // It would be nice to remove an empty buffer at the beginning,
   // but this breaks HTTP.
-  // if (!_writer || !_writer->read_avail())
   if (!_writer) {
     _writer = b;
     init_readers();
@@ -928,12 +806,14 @@ MIOBuffer::append_block_internal(IOBufferBlock *b)
     while (b->read_avail()) {
       _writer = b;
       b       = b->next.get();
-      if (!b)
+      if (!b) {
         break;
+      }
     }
   }
-  while (_writer->next && !_writer->write_avail() && _writer->next->read_avail())
+  while (_writer->next && !_writer->write_avail() && _writer->next->read_avail()) {
     _writer = _writer->next;
+  }
 }
 
 TS_INLINE void
@@ -955,11 +835,7 @@ TS_INLINE void
 MIOBuffer::append_block(int64_t asize_index)
 {
   ink_assert(BUFFER_SIZE_ALLOCATED(asize_index));
-#ifdef TRACK_BUFFER_USER
   IOBufferBlock *b = new_IOBufferBlock_internal(_location);
-#else
-  IOBufferBlock *b = new_IOBufferBlock_internal();
-#endif
   b->alloc(asize_index);
   append_block_internal(b);
   return;
@@ -968,14 +844,17 @@ MIOBuffer::append_block(int64_t asize_index)
 TS_INLINE void
 MIOBuffer::add_block()
 {
-  append_block(size_index);
+  if (this->_writer == nullptr || this->_writer->next == nullptr) {
+    append_block(size_index);
+  }
 }
 
 TS_INLINE void
 MIOBuffer::check_add_block()
 {
-  if (!high_water() && current_low_water())
+  if (!high_water() && current_low_water()) {
     add_block();
+  }
 }
 
 TS_INLINE IOBufferBlock *
@@ -1029,9 +908,10 @@ MIOBuffer::fill(int64_t len)
   while (f < len) {
     _writer->fill(f);
     len -= f;
-    if (len > 0)
+    if (len > 0) {
       _writer = _writer->next;
-    f         = _writer->write_avail();
+    }
+    f = _writer->write_avail();
   }
   _writer->fill(len);
 }
@@ -1040,9 +920,9 @@ TS_INLINE int
 MIOBuffer::max_block_count()
 {
   int maxb = 0;
-  for (int i = 0; i < MAX_MIOBUFFER_READERS; i++) {
-    if (readers[i].allocated()) {
-      int c = readers[i].block_count();
+  for (auto &reader : readers) {
+    if (reader.allocated()) {
+      int c = reader.block_count();
       if (c > maxb) {
         maxb = c;
       }
@@ -1056,52 +936,33 @@ MIOBuffer::max_read_avail()
 {
   int64_t s = 0;
   int found = 0;
-  for (int i = 0; i < MAX_MIOBUFFER_READERS; i++) {
-    if (readers[i].allocated()) {
-      int64_t ss = readers[i].read_avail();
+  for (auto &reader : readers) {
+    if (reader.allocated()) {
+      int64_t ss = reader.read_avail();
       if (ss > s) {
         s = ss;
       }
       found = 1;
     }
   }
-  if (!found && _writer)
+  if (!found && _writer) {
     return _writer->read_avail();
+  }
   return s;
 }
 
 TS_INLINE void
 MIOBuffer::set(void *b, int64_t len)
 {
-#ifdef TRACK_BUFFER_USER
   _writer = new_IOBufferBlock_internal(_location);
-#else
-  _writer          = new_IOBufferBlock_internal();
-#endif
   _writer->set_internal(b, len, BUFFER_SIZE_INDEX_FOR_CONSTANT_SIZE(len));
   init_readers();
 }
 
-TS_INLINE void
-MIOBuffer::set_xmalloced(void *b, int64_t len)
-{
-#ifdef TRACK_BUFFER_USER
-  _writer = new_IOBufferBlock_internal(_location);
-#else
-  _writer          = new_IOBufferBlock_internal();
-#endif
-  _writer->set_internal(b, len, BUFFER_SIZE_INDEX_FOR_XMALLOC_SIZE(len));
-  init_readers();
-}
-
 TS_INLINE void
 MIOBuffer::append_xmalloced(void *b, int64_t len)
 {
-#ifdef TRACK_BUFFER_USER
   IOBufferBlock *x = new_IOBufferBlock_internal(_location);
-#else
-  IOBufferBlock *x = new_IOBufferBlock_internal();
-#endif
   x->set_internal(b, len, BUFFER_SIZE_INDEX_FOR_XMALLOC_SIZE(len));
   append_block_internal(x);
 }
@@ -1109,11 +970,7 @@ MIOBuffer::append_xmalloced(void *b, int64_t len)
 TS_INLINE void
 MIOBuffer::append_fast_allocated(void *b, int64_t len, int64_t fast_size_index)
 {
-#ifdef TRACK_BUFFER_USER
   IOBufferBlock *x = new_IOBufferBlock_internal(_location);
-#else
-  IOBufferBlock *x = new_IOBufferBlock_internal();
-#endif
   x->set_internal(b, len, fast_size_index);
   append_block_internal(x);
 }
@@ -1121,23 +978,12 @@ MIOBuffer::append_fast_allocated(void *b, int64_t len, int64_t fast_size_index)
 TS_INLINE void
 MIOBuffer::alloc(int64_t i)
 {
-#ifdef TRACK_BUFFER_USER
   _writer = new_IOBufferBlock_internal(_location);
-#else
-  _writer          = new_IOBufferBlock_internal();
-#endif
   _writer->alloc(i);
   size_index = i;
   init_readers();
 }
 
-TS_INLINE void
-MIOBuffer::alloc_xmalloc(int64_t buf_size)
-{
-  char *b = (char *)ats_malloc(buf_size);
-  set_xmalloced(b, buf_size);
-}
-
 TS_INLINE void
 MIOBuffer::dealloc_reader(IOBufferReader *e)
 {
@@ -1164,32 +1010,30 @@ IOBufferReader::dealloc()
 TS_INLINE void
 MIOBuffer::dealloc_all_readers()
 {
-  for (int i = 0; i < MAX_MIOBUFFER_READERS; i++)
-    if (readers[i].allocated())
-      dealloc_reader(&readers[i]);
-}
-
-TS_INLINE void
-MIOBuffer::set_size_index(int64_t size)
-{
-  size_index = iobuffer_size_to_index(size);
+  for (auto &reader : readers) {
+    if (reader.allocated()) {
+      dealloc_reader(&reader);
+    }
+  }
 }
 
 TS_INLINE void
 MIOBufferAccessor::reader_for(MIOBuffer *abuf)
 {
   mbuf = abuf;
-  if (abuf)
+  if (abuf) {
     entry = mbuf->alloc_accessor(this);
-  else
-    entry = NULL;
+  } else {
+    entry = nullptr;
+  }
 }
 
 TS_INLINE void
 MIOBufferAccessor::reader_for(IOBufferReader *areader)
 {
-  if (entry == areader)
+  if (entry == areader) {
     return;
+  }
   mbuf  = areader->mbuf;
   entry = areader;
   ink_assert(mbuf);
@@ -1199,12 +1043,8 @@ TS_INLINE void
 MIOBufferAccessor::writer_for(MIOBuffer *abuf)
 {
   mbuf  = abuf;
-  entry = NULL;
+  entry = nullptr;
 }
 
 TS_INLINE
-MIOBufferAccessor::~MIOBufferAccessor()
-{
-}
-
-#endif
+MIOBufferAccessor::~MIOBufferAccessor() {}
