@@ -21,8 +21,7 @@
   limitations under the License.
  */
 
-#ifndef _I_REC_EVENTS_H_
-#define _I_REC_EVENTS_H_
+#pragma once
 
 // copy from mgmt/BaseManager.h
 #define REC_EVENT_SYNC_KEY 10000
@@ -32,11 +31,7 @@
 #define REC_EVENT_CLEAR_STATS 10004
 #define REC_EVENT_CONFIG_FILE_UPDATE 10005
 #define REC_EVENT_PLUGIN_CONFIG_UPDATE 10006
-#define REC_EVENT_HTTP_CLUSTER_DELTA 10007
 #define REC_EVENT_ROLL_LOG_FILES 10008
 #define REC_EVENT_LIBRECORDS 10009
-#define REC_EVENT_CONFIG_FILE_UPDATE_NO_INC_VERSION 10010
 
 #define REC_EVENT_CACHE_DISK_CONTROL 10011
-
-#endif
