@@ -21,13 +21,12 @@
   limitations under the License.
  */
 
-#include "P_RecTree.h"
-#include "stdio.h"
+#include <stdio.h>
 
 int
 main(int argc, char **argv)
 {
-  RecTree *new_rec_tree = new RecTree(NULL);
+  RecTree *new_rec_tree = new RecTree(nullptr);
 
   new_rec_tree->rec_tree_insert("proxy.process.librecords.first_child");
   printf("\n");
