@@ -28,37 +28,46 @@
  *
  *
  ***************************************************************************/
+#include <vector>
 
-#include "ts/ink_platform.h"
-#include "ts/ink_file.h"
-#include "ts/ParseRules.h"
+#include "tscore/ink_platform.h"
+#include "tscore/ink_file.h"
+#include "tscore/ParseRules.h"
+#include "RecordsConfig.h"
+#include "Alarms.h"
 #include "MgmtUtils.h"
 #include "LocalManager.h"
-#include "ClusterCom.h"
 #include "FileManager.h"
-#include "Rollback.h"
+#include "ConfigManager.h"
 #include "WebMgmtUtils.h"
-#include "ts/Diags.h"
-#include "ts/ink_hash_table.h"
+#include "tscore/Diags.h"
 #include "ExpandingArray.h"
-//#include "I_AccCrypto.h"
 
 #include "CoreAPI.h"
 #include "CoreAPIShared.h"
-#include "CfgContextUtils.h"
 #include "EventCallback.h"
-#include "ts/I_Layout.h"
-#include "ts/ink_cap.h"
+#include "tscore/I_Layout.h"
+#include "tscore/ink_cap.h"
+
+#if defined(__FreeBSD__)
+#include <sys/types.h>
+#define __WALL P_ALL
+#define PTRACE_ATTACH PT_ATTACH
+#define PTRACE_DETACH PT_DETACH
+#define DATA_NULL 0
+#else
+#define DATA_NULL NULL
+#endif
 
 // global variable
-CallbackTable *local_event_callbacks;
+static CallbackTable *local_event_callbacks;
 
 extern FileManager *configFiles; // global in traffic_manager
 
 /*-------------------------------------------------------------------------
  * Init
  *-------------------------------------------------------------------------
- * performs any necesary initializations for the local API client,
+ * performs any necessary initializations for the local API client,
  * eg. set up global structures; called by the TSMgmtAPI::TSInit()
  */
 TSMgmtError
@@ -71,7 +80,7 @@ Init(const char * /* socket_path ATS_UNUSED */, TSInitOptionT options)
       return TS_ERR_SYS_CALL;
     }
   } else {
-    local_event_callbacks = NULL;
+    local_event_callbacks = nullptr;
   }
 
   return TS_ERR_OKAY;
@@ -80,7 +89,7 @@ Init(const char * /* socket_path ATS_UNUSED */, TSInitOptionT options)
 /*-------------------------------------------------------------------------
  * Terminate
  *-------------------------------------------------------------------------
- * performs any necesary cleanup of global structures, etc,
+ * performs any necessary cleanup of global structures, etc,
  * for the local API client,
  */
 TSMgmtError
@@ -113,7 +122,7 @@ ProxyShutdown()
 
   lmgmt->processShutdown(false /* only shut down the proxy*/);
 
-  // Wait for awhile for shtudown to happen
+  // Wait for awhile for shutdown to happen
   do {
     mgmt_sleep_sec(1);
     i++;
@@ -153,7 +162,6 @@ ProxyStateGet()
 TSMgmtError
 ProxyStateSet(TSProxyStateT state, TSCacheClearT clear)
 {
-  int i = 0;
   char tsArgs[MAX_BUF_SIZE];
   char *proxy_options;
 
@@ -172,7 +180,12 @@ ProxyStateSet(TSProxyStateT state, TSCacheClearT clear)
 
     // Start with the default options from records.config.
     if (RecGetRecordString_Xmalloc("proxy.config.proxy_binary_opts", &proxy_options) == REC_ERR_OKAY) {
-      snprintf(tsArgs, sizeof(tsArgs), "%s", proxy_options);
+      if (max_records_entries ==
+          (REC_INTERNAL_RECORDS + REC_DEFAULT_API_RECORDS)) { // Default size, don't need to pass down to _server
+        snprintf(tsArgs, sizeof(tsArgs), "%s", proxy_options);
+      } else {
+        snprintf(tsArgs, sizeof(tsArgs), "%s --maxRecords %d", proxy_options, max_records_entries);
+      }
       ats_free(proxy_options);
     }
 
@@ -184,24 +197,16 @@ ProxyStateSet(TSProxyStateT state, TSCacheClearT clear)
       ink_strlcat(tsArgs, " -k", sizeof(tsArgs));
     }
 
-    if (strlen(tsArgs) > 0) { /* Passed command line args for proxy */
-      ats_free(lmgmt->proxy_options);
-      lmgmt->proxy_options = ats_strdup(tsArgs);
-      mgmt_log("[ProxyStateSet] Traffic Server Args: '%s'\n", lmgmt->proxy_options);
-    }
+    mgmt_log("[ProxyStateSet] Traffic Server Args: '%s %s'\n", lmgmt->proxy_options.c_str(), tsArgs);
 
     lmgmt->run_proxy = true;
     lmgmt->listenForProxy();
-
-    do {
-      mgmt_sleep_sec(1);
-    } while (i++ < 20 && (lmgmt->proxy_running == 0));
-
-    if (!lmgmt->processRunning()) {
+    if (!lmgmt->startProxy(tsArgs)) {
       goto Lerror;
     }
 
     break;
+
   default:
     goto Lerror;
   }
@@ -219,23 +224,23 @@ Lerror:
 #include <sys/ptrace.h>
 #include <cxxabi.h>
 
-typedef Vec<pid_t> threadlist;
+using threadlist = std::vector<pid_t>;
 
 static threadlist
 threads_for_process(pid_t proc)
 {
-  DIR *dir             = NULL;
-  struct dirent *entry = NULL;
+  DIR *dir             = nullptr;
+  struct dirent *entry = nullptr;
 
   char path[64];
   threadlist threads;
 
-  if (snprintf(path, sizeof(path), "/proc/%ld/task", (long)proc) >= (int)sizeof(path)) {
+  if (snprintf(path, sizeof(path), "/proc/%ld/task", static_cast<long>(proc)) >= static_cast<int>(sizeof(path))) {
     goto done;
   }
 
   dir = opendir(path);
-  if (dir == NULL) {
+  if (dir == nullptr) {
     goto done;
   }
 
@@ -246,7 +251,7 @@ threads_for_process(pid_t proc)
       continue;
     }
 
-    threadid = strtol(entry->d_name, NULL, 10);
+    threadid = strtol(entry->d_name, nullptr, 10);
     if (threadid > 0) {
       threads.push_back(threadid);
       Debug("backtrace", "found thread %ld", (long)threadid);
@@ -262,12 +267,12 @@ done:
 }
 
 static void
-backtrace_for_thread(pid_t threadid, textBuffer &text)
+backtrace_for_thread(pid_t threadid, TextBuffer &text)
 {
   int status;
-  unw_addr_space_t addr_space = NULL;
+  unw_addr_space_t addr_space = nullptr;
   unw_cursor_t cursor;
-  void *ap       = NULL;
+  void *ap       = nullptr;
   pid_t target   = -1;
   unsigned level = 0;
 
@@ -288,13 +293,13 @@ backtrace_for_thread(pid_t threadid, textBuffer &text)
 
   ap = _UPT_create(threadid);
   Debug("backtrace", "created UPT %p", ap);
-  if (ap == NULL) {
+  if (ap == nullptr) {
     goto done;
   }
 
   addr_space = unw_create_addr_space(&_UPT_accessors, 0 /* byteorder */);
   Debug("backtrace", "created address space %p", addr_space);
-  if (addr_space == NULL) {
+  if (addr_space == nullptr) {
     goto done;
   }
 
@@ -313,11 +318,11 @@ backtrace_for_thread(pid_t threadid, textBuffer &text)
 
     if (unw_get_proc_name(&cursor, buf, sizeof(buf), &offset) == 0) {
       int status;
-      char *name = abi::__cxa_demangle(buf, NULL, NULL, &status);
-      text.format("%-4u 0x%016llx %s + %p\n", level, (unsigned long long)ip, name ? name : buf, (void *)offset);
+      char *name = abi::__cxa_demangle(buf, nullptr, nullptr, &status);
+      text.format("%-4u 0x%016llx %s + %p\n", level, static_cast<unsigned long long>(ip), name ? name : buf, (void *)offset);
       free(name);
     } else {
-      text.format("%-4u 0x%016llx 0x0 + %p\n", level, (unsigned long long)ip, (void *)offset);
+      text.format("%-4u 0x%016llx 0x0 + %p\n", level, static_cast<unsigned long long>(ip), (void *)offset);
     }
 
     ++level;
@@ -332,38 +337,38 @@ done:
     _UPT_destroy(ap);
   }
 
-  status = ptrace(PTRACE_DETACH, target, NULL, NULL);
+  status = ptrace(PTRACE_DETACH, target, NULL, DATA_NULL);
   Debug("backtrace", "ptrace(DETACH, %ld) -> %d (errno %d)", (long)target, status, errno);
 }
 
 TSMgmtError
 ServerBacktrace(unsigned /* options */, char **trace)
 {
-  *trace = NULL;
+  *trace = nullptr;
 
   // Unfortunately, we need to be privileged here. We either need to be root or to be holding
   // the CAP_SYS_PTRACE capability. Even though we are the parent traffic_manager, it is not
   // traceable without privilege because the process credentials do not match.
   ElevateAccess access(ElevateAccess::TRACE_PRIVILEGE);
   threadlist threads(threads_for_process(lmgmt->watched_process_pid));
-  textBuffer text(0);
+  TextBuffer text(0);
 
-  Debug("backtrace", "tracing %zd threads for traffic_server PID %ld", threads.count(), (long)lmgmt->watched_process_pid);
-  for_Vec(pid_t, threadid, threads)
-  {
+  Debug("backtrace", "tracing %zd threads for traffic_server PID %ld", threads.size(), (long)lmgmt->watched_process_pid);
+
+  for (auto threadid : threads) {
     Debug("backtrace", "tracing thread %ld", (long)threadid);
     // Get the thread name using /proc/PID/comm
     ats_scoped_fd fd;
     char threadname[128];
 
-    snprintf(threadname, sizeof(threadname), "/proc/%ld/comm", (long)threadid);
+    snprintf(threadname, sizeof(threadname), "/proc/%ld/comm", static_cast<long>(threadid));
     fd = open(threadname, O_RDONLY);
     if (fd >= 0) {
-      text.format("Thread %ld, ", (long)threadid);
+      text.format("Thread %ld, ", static_cast<long>(threadid));
       text.readFromFD(fd);
       text.chomp();
     } else {
-      text.format("Thread %ld", (long)threadid);
+      text.format("Thread %ld", static_cast<long>(threadid));
     }
 
     text.format(":\n");
@@ -381,7 +386,7 @@ ServerBacktrace(unsigned /* options */, char **trace)
 TSMgmtError
 ServerBacktrace(unsigned /* options */, char **trace)
 {
-  *trace = NULL;
+  *trace = nullptr;
   return TS_ERR_NOT_SUPPORTED;
 }
 
@@ -397,7 +402,7 @@ Reconfigure()
 {
   configFiles->rereadConfig();                              // TM rereads
   lmgmt->signalEvent(MGMT_EVENT_PLUGIN_CONFIG_UPDATE, "*"); // TS rereads
-  RecSetRecordInt("proxy.node.config.reconfigure_time", time(NULL), REC_SOURCE_DEFAULT);
+  RecSetRecordInt("proxy.node.config.reconfigure_time", time(nullptr), REC_SOURCE_DEFAULT);
   RecSetRecordInt("proxy.node.config.reconfigure_required", 0, REC_SOURCE_DEFAULT);
 
   return TS_ERR_OKAY;
@@ -412,13 +417,8 @@ Reconfigure()
 TSMgmtError
 Restart(unsigned options)
 {
-  if (options & TS_RESTART_OPT_CLUSTER) {
-    // Enqueue an event to restart the proxies across the cluster
-    // this will kill TM completely;traffic_cop will restart TM/TS
-    lmgmt->ccom->sendClusterMessage(CLUSTER_MSG_SHUTDOWN_MANAGER);
-  } else {
-    lmgmt->mgmt_shutdown_outstanding = (options & TS_RESTART_OPT_DRAIN) ? MGMT_PENDING_IDLE_RESTART : MGMT_PENDING_RESTART;
-  }
+  lmgmt->mgmt_shutdown_triggered_at = time(nullptr);
+  lmgmt->mgmt_shutdown_outstanding  = (options & TS_RESTART_OPT_DRAIN) ? MGMT_PENDING_IDLE_RESTART : MGMT_PENDING_RESTART;
 
   return TS_ERR_OKAY;
 }
@@ -431,15 +431,50 @@ Restart(unsigned options)
 TSMgmtError
 Bounce(unsigned options)
 {
-  if (options & TS_RESTART_OPT_CLUSTER) {
-    lmgmt->ccom->sendClusterMessage(CLUSTER_MSG_BOUNCE_PROCESS);
-  } else {
-    lmgmt->mgmt_shutdown_outstanding = (options & TS_RESTART_OPT_DRAIN) ? MGMT_PENDING_IDLE_BOUNCE : MGMT_PENDING_BOUNCE;
-  }
+  lmgmt->mgmt_shutdown_triggered_at = time(nullptr);
+  lmgmt->mgmt_shutdown_outstanding  = (options & TS_RESTART_OPT_DRAIN) ? MGMT_PENDING_IDLE_BOUNCE : MGMT_PENDING_BOUNCE;
 
   return TS_ERR_OKAY;
 }
 
+/*-------------------------------------------------------------------------
+ * Stop
+ *-------------------------------------------------------------------------
+ * Stops traffic_server process(es).
+ */
+TSMgmtError
+Stop(unsigned options)
+{
+  lmgmt->mgmt_shutdown_triggered_at = time(nullptr);
+  lmgmt->mgmt_shutdown_outstanding  = (options & TS_STOP_OPT_DRAIN) ? MGMT_PENDING_IDLE_STOP : MGMT_PENDING_STOP;
+
+  return TS_ERR_OKAY;
+}
+
+/*-------------------------------------------------------------------------
+ * Drain
+ *-------------------------------------------------------------------------
+ * Drain requests of traffic_server
+ */
+TSMgmtError
+Drain(unsigned options)
+{
+  switch (options) {
+  case TS_DRAIN_OPT_NONE:
+    lmgmt->mgmt_shutdown_outstanding = MGMT_PENDING_DRAIN;
+    break;
+  case TS_DRAIN_OPT_IDLE:
+    lmgmt->mgmt_shutdown_outstanding = MGMT_PENDING_IDLE_DRAIN;
+    break;
+  case TS_DRAIN_OPT_UNDO:
+    lmgmt->mgmt_shutdown_outstanding = MGMT_PENDING_UNDO_DRAIN;
+    break;
+  default:
+    ink_release_assert(!"Not expected to reach here");
+  }
+  return TS_ERR_OKAY;
+}
+
 /*-------------------------------------------------------------------------
  * StorageDeviceCmdOffline
  *-------------------------------------------------------------------------
@@ -460,7 +495,7 @@ StorageDeviceCmdOffline(const char *dev)
  * Signal plugins.
  */
 TSMgmtError
-LifecycleMessage(char const *tag, void const *data, size_t data_size)
+LifecycleMessage(const char *tag, void const *data, size_t data_size)
 {
   ink_release_assert(!"Not expected to reach here");
   lmgmt->signalEvent(MGMT_EVENT_LIFECYCLE_MESSAGE, tag);
@@ -498,7 +533,7 @@ MgmtRecordGet(const char *rec_name, TSRecordEle *rec_ele)
     if (!varCounterFromName(rec_name, &(counter_val))) {
       return TS_ERR_FAIL;
     }
-    rec_ele->valueT.counter_val = (TSCounter)counter_val;
+    rec_ele->valueT.counter_val = static_cast<TSCounter>(counter_val);
 
     Debug("RecOp", "[MgmtRecordGet] Get Counter Var %s = %" PRId64 "", rec_ele->rec_name, rec_ele->valueT.counter_val);
     break;
@@ -508,7 +543,7 @@ MgmtRecordGet(const char *rec_name, TSRecordEle *rec_ele)
     if (!varIntFromName(rec_name, &(int_val))) {
       return TS_ERR_FAIL;
     }
-    rec_ele->valueT.int_val = (TSInt)int_val;
+    rec_ele->valueT.int_val = static_cast<TSInt>(int_val);
 
     Debug("RecOp", "[MgmtRecordGet] Get Int Var %s = %" PRId64 "", rec_ele->rec_name, rec_ele->valueT.int_val);
     break;
@@ -539,7 +574,7 @@ MgmtRecordGet(const char *rec_name, TSRecordEle *rec_ele)
     Debug("RecOp", "[MgmtRecordGet] Get String Var %s = %s", rec_ele->rec_name, rec_ele->valueT.string_val);
     break;
 
-  default: // UNKOWN TYPE
+  default: // UNKNOWN TYPE
     Debug("RecOp", "[MgmtRecordGet] Get Failed : %d is Unknown Var type %s", rec_type, rec_name);
     return TS_ERR_FAIL;
   }
@@ -712,118 +747,6 @@ MgmtRecordSetString(const char *rec_name, const char *string_val, TSActionNeedT
   return MgmtRecordSet(rec_name, string_val, action_need);
 }
 
-/**************************************************************************
- * FILE OPERATIONS
- *************************************************************************/
-
-/*-------------------------------------------------------------------------
- * ReadFile (MgmtAPILocal::get_lines_from_file)
- *-------------------------------------------------------------------------
- * Purpose: returns copy of the most recent version of the file
- * Input:   file - the config file to read
- *          text - a buffer is allocated on the text char* pointer
- *          size - the size of the buffer is returned
- *          ver  - the version number of file being read
- * Note: CALLEE must DEALLOCATE text memory returned
- */
-TSMgmtError
-ReadFile(TSFileNameT file, char **text, int *size, int *version)
-{
-  const char *fname;
-  Rollback *file_rb;
-  int ret, old_file_len;
-  textBuffer *old_file_content;
-  char *old_file_lines;
-  version_t ver;
-
-  Debug("FileOp", "[get_lines_from_file] START");
-
-  fname = filename_to_string(file);
-  if (!fname) {
-    return TS_ERR_READ_FILE;
-  }
-
-  ret = configFiles->getRollbackObj(fname, &file_rb);
-  if (ret != true) {
-    Debug("FileOp", "[get_lines_from_file] Can't get Rollback for file: %s", fname);
-    return TS_ERR_READ_FILE;
-  }
-  ver = file_rb->getCurrentVersion();
-  file_rb->getVersion(ver, &old_file_content);
-  *version = ver;
-
-  // don't need to allocate memory b/c "getVersion" allocates memory
-  old_file_lines = old_file_content->bufPtr();
-  old_file_len   = strlen(old_file_lines);
-
-  *text = ats_strdup(old_file_lines); // make copy before deleting textBuffer
-  *size = old_file_len;
-
-  delete old_file_content; // delete textBuffer
-
-  return TS_ERR_OKAY;
-}
-
-/*-------------------------------------------------------------------------
- * WriteFile
- *-------------------------------------------------------------------------
- * Purpose: replaces the current file with the file passed in;
- *  does forceUpdate for Rollback and FileManager so correct file
- *  versioning is maintained
- * Input: file - the config file to write
- *        text - text buffer to write
- *        size - the size of the buffer to write
- *        version - the current version level; new file will have the
- *                  version number above this one
- */
-TSMgmtError
-WriteFile(TSFileNameT file, const char *text, int size, int version)
-{
-  const char *fname;
-  Rollback *file_rb;
-  textBuffer *file_content;
-  int ret;
-  version_t ver;
-
-  fname = filename_to_string(file);
-  if (!fname) {
-    return TS_ERR_WRITE_FILE;
-  }
-
-  // get rollback object for config file
-  mgmt_log("[CfgFileIO::WriteFile] %s\n", fname);
-  if (!(configFiles->getRollbackObj(fname, &file_rb))) {
-    mgmt_log("[CfgFileIO::WriteFile] ERROR getting rollback object\n");
-    // goto generate_error_msg;
-  }
-
-  // if version < 0 then, just use next version in sequence;
-  // otherwise check if trying to commit an old version
-  if (version >= 0) {
-    // check that the current version is equal to or less than the version
-    // that wants to be written
-    ver = file_rb->getCurrentVersion();
-    if (ver != version) { // trying to commit an old version
-      return TS_ERR_WRITE_FILE;
-    }
-  }
-  // use rollback object to update file with new content
-  file_content = new textBuffer(size + 1);
-  ret          = file_content->copyFrom(text, size);
-  if (ret < 0) {
-    delete file_content;
-    return TS_ERR_WRITE_FILE;
-  }
-
-  if ((file_rb->forceUpdate(file_content, -1)) != OK_ROLLBACK) {
-    delete file_content;
-    return TS_ERR_WRITE_FILE;
-  }
-
-  delete file_content;
-  return TS_ERR_OKAY;
-}
-
 /**************************************************************************
  * EVENTS
  *************************************************************************/
@@ -881,12 +804,6 @@ EventResolve(const char *event_name)
 TSMgmtError
 ActiveEventGetMlt(LLQ *active_events)
 {
-  InkHashTable *event_ht;
-  InkHashTableEntry *entry;
-  InkHashTableIteratorState iterator_state;
-  int event_id;
-  char *event_name;
-
   if (!active_events) {
     return TS_ERR_PARAMS;
   }
@@ -894,16 +811,13 @@ ActiveEventGetMlt(LLQ *active_events)
   // Alarms stores a hashtable of all active alarms where:
   // key = alarm_t,
   // value = alarm_description defined in Alarms.cc alarmText[] array
-  event_ht = lmgmt->alarm_keeper->getLocalAlarms();
+  std::unordered_map<std::string, Alarm *> const &event_ht = lmgmt->alarm_keeper->getLocalAlarms();
 
   // iterate through hash-table and insert event_name's into active_events list
-  for (entry = ink_hash_table_iterator_first(event_ht, &iterator_state); entry != NULL;
-       entry = ink_hash_table_iterator_next(event_ht, &iterator_state)) {
-    char *key = (char *)ink_hash_table_entry_key(event_ht, entry);
-
+  for (auto &&it : event_ht) {
     // convert key to int; insert into llQ
-    event_id   = ink_atoi(key);
-    event_name = get_event_name(event_id);
+    int event_id     = ink_atoi(it.first.c_str());
+    char *event_name = get_event_name(event_id);
     if (event_name) {
       if (!enqueue(active_events, event_name)) { // returns true if successful
         return TS_ERR_FAIL;
@@ -952,12 +866,12 @@ EventIsActive(const char *event_name, bool *is_current)
  * only allow registering callbacks for general alarms.
  * Mimic remote side and have a separate structure (eg. hashtable) of
  * event callback functions for each type of event. The functions are also
- * stored in the the hashtable, not in the TM alarm processor model
+ * stored in the hashtable, not in the TM alarm processor model
  */
 TSMgmtError
 EventSignalCbRegister(const char *event_name, TSEventSignalFunc func, void *data)
 {
-  return cb_table_register(local_event_callbacks, event_name, func, data, NULL);
+  return cb_table_register(local_event_callbacks, event_name, func, data, nullptr);
 }
 
 /*-------------------------------------------------------------------------
@@ -971,88 +885,35 @@ EventSignalCbUnregister(const char *event_name, TSEventSignalFunc func)
   return cb_table_unregister(local_event_callbacks, event_name, func);
 }
 
-/***************************************************************************
- * Snapshots
- ***************************************************************************/
+/*-------------------------------------------------------------------------
+ * HostStatusSetDown
+ *-------------------------------------------------------------------------
+ * Sets the HOST status to Down
+ *
+ * 'marshalled_req' is marshalled here, (host_name and down_time, na).
+ * 'len' is the length of the 'req' marshaled data.
+ * 'na' unused.
+ */
 TSMgmtError
-SnapshotTake(const char *snapshot_name)
+HostStatusSetDown(const char *marshalled_req, int len, const char *na)
 {
-  ats_scoped_str snapdir;
-
-  if (!snapshot_name) {
-    return TS_ERR_PARAMS;
-  }
-
-  snapdir = RecConfigReadSnapshotDir();
-
-  SnapResult result = configFiles->takeSnap(snapshot_name, snapdir);
-  if (result != SNAP_OK) {
-    return TS_ERR_FAIL;
-  } else {
-    return TS_ERR_OKAY;
-  }
+  lmgmt->hostStatusSetDown(marshalled_req, len);
+  return TS_ERR_OKAY;
 }
 
+/*-------------------------------------------------------------------------
+ * HostStatusSetUp
+ *-------------------------------------------------------------------------
+ * Sets the HOST status to Up
+ *
+ * 'marshalled_req' is marshalled here, host_name.
+ * 'len' is the length of 'req'
+ * 'na' unused.
+ */
 TSMgmtError
-SnapshotRestore(const char *snapshot_name)
+HostStatusSetUp(const char *marshalled_req, int len, const char *na)
 {
-  ats_scoped_str snapdir;
-
-  if (!snapshot_name) {
-    return TS_ERR_PARAMS;
-  }
-
-  snapdir = RecConfigReadSnapshotDir();
-
-  SnapResult result = configFiles->restoreSnap(snapshot_name, snapdir);
-  if (result != SNAP_OK) {
-    return TS_ERR_FAIL;
-  } else {
-    return TS_ERR_OKAY;
-  }
-}
-
-TSMgmtError
-SnapshotRemove(const char *snapshot_name)
-{
-  ats_scoped_str snapdir;
-
-  if (!snapshot_name) {
-    return TS_ERR_PARAMS;
-  }
-
-  snapdir = RecConfigReadSnapshotDir();
-
-  SnapResult result = configFiles->removeSnap(snapshot_name, snapdir);
-  if (result != SNAP_OK) {
-    return TS_ERR_FAIL;
-  } else {
-    return TS_ERR_OKAY;
-  }
-}
-
-/* based on FileManager.cc::displaySnapOption() */
-TSMgmtError
-SnapshotGetMlt(LLQ *snapshots)
-{
-  ExpandingArray snap_list(25, true);
-  SnapResult snap_result;
-  int num_snaps;
-  char *snap_name;
-
-  snap_result = configFiles->WalkSnaps(&snap_list);
-  if (snap_result != SNAP_OK) {
-    return TS_ERR_FAIL;
-  }
-
-  num_snaps = snap_list.getNumEntries();
-  for (int i = 0; i < num_snaps; i++) {
-    snap_name = (char *)(snap_list[i]);
-    if (snap_name) {
-      enqueue(snapshots, ats_strdup(snap_name));
-    }
-  }
-
+  lmgmt->hostStatusSetUp(marshalled_req, len);
   return TS_ERR_OKAY;
 }
 
@@ -1066,16 +927,8 @@ SnapshotGetMlt(LLQ *snapshots)
  * stats are set back to defaults successfully.
  */
 TSMgmtError
-StatsReset(bool cluster, const char *name)
+StatsReset(const char *name)
 {
-  if (cluster) {
-    lmgmt->ccom->sendClusterMessage(CLUSTER_MSG_CLEAR_STATS, name);
-  } else {
-    lmgmt->clearStats(name);
-  }
+  lmgmt->clearStats(name);
   return TS_ERR_OKAY;
 }
-
-/*-------------------------------------------------------------
- * rmserver.cfg
- *-------------------------------------------------------------*/
