@@ -304,6 +304,8 @@ ts_lua_schedule(lua_State *L)
 
   ci = ts_lua_get_cont_info(L);
   if (ci == NULL) {
+    TSError("[ts_lua][%s] no cont info found", __FUNCTION__);
+    TSReleaseAssert(!"Unexpected fetch of cont info");
     return 0;
   }
 
@@ -402,6 +404,8 @@ ts_lua_sleep(lua_State *L)
 
   ci = ts_lua_get_cont_info(L);
   if (ci == NULL) {
+    TSError("[ts_lua][%s] no cont info found", __FUNCTION__);
+    TSReleaseAssert(!"Unexpected fetch of cont info");
     return 0;
   }
 
@@ -462,6 +466,8 @@ ts_lua_host_lookup(lua_State *L)
 
   ci = ts_lua_get_cont_info(L);
   if (ci == NULL) {
+    TSError("[ts_lua][%s] no cont info found", __FUNCTION__);
+    TSReleaseAssert(!"Unexpected fetch of cont info");
     return 0;
   }
 
