@@ -488,7 +488,19 @@ public:
     if (_conf_rld_act != nullptr && !TSActionDone(_conf_rld_act)) {
       TSActionCancel(_conf_rld_act);
     }
-    _conf_rld_act = TSContScheduleOnPool(_conf_rld, delay * 1000, TS_THREAD_POOL_NET);
+    _conf_rld_act = TSContScheduleOnPool(_conf_rld, delay * 1000, TS_THREAD_POOL_TASK);
+  }
+
+  /**
+     Clear _conf_rld_act if the event handler is handling the action
+   */
+  void
+  check_current_action(void *edata)
+  {
+    // Following what's TSContScheduleOnPool does before returning TSAction
+    if (_conf_rld_act == ((TSAction)((uintptr_t)edata | 0x1))) {
+      _conf_rld_act = nullptr;
+    }
   }
 
   ts::shared_mutex reload_mutex;
@@ -1038,7 +1050,9 @@ int
 config_reloader(TSCont cont, TSEvent event, void *edata)
 {
   TSDebug(PLUGIN_NAME, "reloading configs");
-  S3Config *s3          = static_cast<S3Config *>(TSContDataGet(cont));
+  S3Config *s3 = static_cast<S3Config *>(TSContDataGet(cont));
+  s3->check_current_action(edata);
+
   S3Config *file_config = gConfCache.get(s3->conf_fname());
 
   if (!file_config || !file_config->valid()) {
