@@ -28,11 +28,11 @@
 
  ****************************************************************************/
 
-#include "ts/ink_config.h"
+#include "tscore/ink_config.h"
 #include "ProxyConfig.h"
 #include "StatPages.h"
 #include "HdrUtils.h"
-#include "ts/MatcherUtils.h"
+#include "tscore/MatcherUtils.h"
 
 #define MAX_STAT_PAGES 32
 
@@ -44,22 +44,25 @@ static struct {
   StatPagesFunc func;
 } stat_pages[MAX_STAT_PAGES];
 
-static volatile int n_stat_pages = 0;
+static int n_stat_pages;
 
 void
 StatPagesManager::init()
 {
+  ink_mutex_init(&stat_pages_mutex);
   REC_EstablishStaticConfigInt32(m_enabled, "proxy.config.http_ui_enabled");
 }
 
 void
 StatPagesManager::register_http(const char *module, StatPagesFunc func)
 {
+  ink_mutex_acquire(&stat_pages_mutex);
   ink_release_assert(n_stat_pages < MAX_STAT_PAGES);
 
-  stat_pages[n_stat_pages].module = (char *)ats_malloc(strlen(module) + 3);
+  stat_pages[n_stat_pages].module = static_cast<char *>(ats_malloc(strlen(module) + 3));
   snprintf(stat_pages[n_stat_pages].module, strlen(module) + 3, "{%s}", module);
   stat_pages[n_stat_pages++].func = func;
+  ink_mutex_release(&stat_pages_mutex);
 }
 
 Action *
@@ -89,7 +92,7 @@ StatPagesManager::handle_http(Continuation *cont, HTTPHdr *header)
     }
   }
 
-  cont->handleEvent(STAT_PAGE_FAILURE, 0);
+  cont->handleEvent(STAT_PAGE_FAILURE, nullptr);
   return ACTION_RESULT_DONE;
 }
 
@@ -105,7 +108,7 @@ StatPagesManager::is_stat_page(URL *url)
   const char *h = url->host_get(&length);
   char host[MAXDNAME + 1];
 
-  if (h == NULL || length < 2 || length > MAXDNAME) {
+  if (h == nullptr || length < 2 || length > MAXDNAME) {
     return false;
   }
 
@@ -127,7 +130,7 @@ StatPagesManager::is_cache_inspector_page(URL *url)
   const char *h = url->host_get(&length);
   char host[MAXDNAME + 1];
 
-  if (h == NULL || length < 2 || length > MAXDNAME) {
+  if (h == nullptr || length < 2 || length > MAXDNAME) {
     return false;
   }
 
@@ -146,7 +149,7 @@ void
 BaseStatPagesHandler::resp_clear()
 {
   ats_free(response);
-  response        = NULL;
+  response        = nullptr;
   response_size   = 0;
   response_length = 0;
 }
@@ -173,9 +176,9 @@ BaseStatPagesHandler::resp_add(const char *fmt, ...)
 
   if (size != response_size) {
     if (!response) {
-      response = (char *)ats_malloc(size);
+      response = static_cast<char *>(ats_malloc(size));
     } else {
-      response = (char *)ats_realloc(response, size);
+      response = static_cast<char *>(ats_realloc(response, size));
     }
     response_size = size;
   }
