@@ -45,10 +45,8 @@ public:
 
   static void convert_request(HTTPVersion outgoing_ver, HTTPHdr *outgoing_request);
   static void convert_response(HTTPVersion outgoing_ver, HTTPHdr *outgoing_response);
-  static void convert_to_0_9_request_header(HTTPHdr *outgoing_request);
   static void convert_to_1_0_request_header(HTTPHdr *outgoing_request);
   static void convert_to_1_1_request_header(HTTPHdr *outgoing_request);
-  static void convert_to_0_9_response_header(HTTPHdr *outgoing_response);
   static void convert_to_1_0_response_header(HTTPHdr *outgoing_response);
   static void convert_to_1_1_response_header(HTTPHdr *outgoing_response);
 
@@ -58,6 +56,7 @@ public:
   static bool downgrade_request(bool *origin_server_keep_alive, HTTPHdr *outgoing_request);
   static bool is_method_safe(int method);
   static bool is_method_idempotent(int method);
+  static bool is_status_an_error_response(HTTPStatus response_code);
 
   static void generate_and_set_squid_codes(HTTPHdr *header, char *via_string, HttpTransact::SquidLogInfo *squid_codes);
 
