@@ -32,6 +32,7 @@
 #include "tscore/ink_file.h"
 #include "tscore/Tokenizer.h"
 #include "tscore/ts_file.h"
+#include "tscore/Filenames.h"
 #include "IPAllow.h"
 #include "PluginFactory.h"
 
@@ -45,7 +46,7 @@ load_remap_file_func load_remap_file_cb = nullptr;
   Returns the length of the URL.
 
   Will replace the terminator with a '/' if this is a full URL and
-  there are no '/' in it after the the host.  This ensures that class
+  there are no '/' in it after the host.  This ensures that class
   URL parses the URL correctly.
 
 */
@@ -100,6 +101,18 @@ BUILD_TABLE_INFO::reset()
   clear_xstr_array(this->argv, sizeof(this->argv) / sizeof(char *));
 }
 
+void
+BUILD_TABLE_INFO::clear_acl_rules_list()
+{
+  // clean up any leftover named filter rules
+  auto *rp = rules_list;
+  while (rp != nullptr) {
+    auto *tmp = rp->next;
+    delete rp;
+    rp = tmp;
+  }
+}
+
 static const char *
 process_filter_opt(url_mapping *mp, const BUILD_TABLE_INFO *bti, char *errStrBuf, int errStrBufSize)
 {
@@ -147,7 +160,7 @@ is_inkeylist(const char *key, ...)
   va_start(ap, key);
 
   const char *str = va_arg(ap, const char *);
-  for (unsigned idx = 1; str; idx++) {
+  while (str) {
     if (!strcasecmp(key, str)) {
       va_end(ap);
       return true;
@@ -299,7 +312,7 @@ parse_remap_fragment(const char *path, BUILD_TABLE_INFO *bti, char *errbuf, size
   if (success) {
     // register the included file with the management subsystem so that we can correctly
     // reload them when they change
-    load_remap_file_cb(path);
+    load_remap_file_cb(ts::filename::REMAP, path);
   } else {
     snprintf(errbuf, errbufsize, "failed to parse included file %s", path);
     return (const char *)errbuf;
@@ -449,6 +462,7 @@ remap_validate_filter_args(acl_filter_rule **rule_pp, const char **argv, int arg
     Debug("url_rewrite", "[validate_filter_args] new acl_filter_rule class was created during remap rule processing");
   }
 
+  bool action_flag = false;
   for (i = 0; i < argc; i++) {
     unsigned long ul;
     bool hasarg;
@@ -571,6 +585,13 @@ remap_validate_filter_args(acl_filter_rule **rule_pp, const char **argv, int arg
     }
 
     if (ul & REMAP_OPTFLG_ACTION) { /* "action=" option */
+      if (action_flag) {
+        std::string_view err = "Only one @action= is allowed per remap ACL";
+        Debug("url_rewrite", "%s", err.data());
+        // For 9.2.x, making Warning instead of Error for compatibility
+        Warning("%s", err.data());
+      }
+      action_flag = true;
       if (is_inkeylist(argptr, "0", "off", "deny", "disable", nullptr)) {
         rule->allow_flag = 0;
       } else if (is_inkeylist(argptr, "1", "on", "allow", "enable", nullptr)) {
@@ -898,11 +919,10 @@ process_regex_mapping_config(const char *from_host_lower, url_mapping *new_mappi
   return true;
 
 lFail:
-  if (reg_map->to_url_host_template) {
-    ats_free(reg_map->to_url_host_template);
-    reg_map->to_url_host_template     = nullptr;
-    reg_map->to_url_host_template_len = 0;
-  }
+  ats_free(reg_map->to_url_host_template);
+  reg_map->to_url_host_template     = nullptr;
+  reg_map->to_url_host_template_len = 0;
+
   return false;
 }
 
@@ -1365,5 +1385,7 @@ remap_parse_config(const char *path, UrlRewrite *rewrite)
    * accordingly notify all plugins that we are done */
   rewrite->pluginFactory.indicatePostReload(status);
 
+  bti.clear_acl_rules_list();
+
   return status;
 }
