@@ -61,6 +61,9 @@ struct BUILD_TABLE_INFO {
   // Clear the argument vector.
   void reset();
 
+  // Free acl_filter_rule in the list
+  void clear_acl_rules_list();
+
   // noncopyable
   BUILD_TABLE_INFO(const BUILD_TABLE_INFO &) = delete;            // disabled
   BUILD_TABLE_INFO &operator=(const BUILD_TABLE_INFO &) = delete; // disabled
@@ -76,6 +79,6 @@ unsigned long remap_check_option(const char **argv, int argc, unsigned long find
 
 bool remap_parse_config(const char *path, UrlRewrite *rewrite);
 
-typedef void (*load_remap_file_func)(const char *);
+typedef void (*load_remap_file_func)(const char *, const char *);
 
 extern load_remap_file_func load_remap_file_cb;
