@@ -92,7 +92,7 @@ public:
       break;
     case LOG_FILE_ASCII:
     case LOG_FILE_PIPE:
-      free(m_data);
+      ats_free(m_data);
       break;
     case N_LOGFILE_TYPES:
     default:
@@ -190,8 +190,6 @@ public:
   static LogConfig *config;
   static LogFieldList global_field_list;
   static std::unordered_map<std::string, LogField *> field_symbol_hash;
-  static LogFormat *global_scrap_format;
-  static LogObject *global_scrap_object;
   static LoggingMode logging_mode;
 
   // logging thread stuff
@@ -205,9 +203,18 @@ public:
 
   // reconfiguration stuff
   static void change_configuration();
+
   static int handle_logging_mode_change(const char *name, RecDataT data_type, RecData data, void *cookie);
   static int handle_periodic_tasks_int_change(const char *name, RecDataT data_type, RecData data, void *cookie);
 
+  /** Check each log file path to see whether it exists and re-open if not.
+   *
+   * This is called when an external log rotation entity has moved log files to
+   * rolled names. This checks whether the original log file exists and, if
+   * not, closes the file descriptor and re-opens the file.
+   */
+  static int handle_log_rotation_request();
+
   friend void RegressionTest_LogObjectManager_Transfer(RegressionTest *, int, int *);
 
 private:
@@ -218,9 +225,16 @@ private:
   static int init_status;
   static int config_flags;
   static bool logging_mode_changed;
+  static bool log_rotate_signal_received;
   static uint32_t periodic_tasks_interval;
 };
 
+static inline bool
+LogThrottlingIsValid(int throttling_val)
+{
+  return throttling_val >= 0;
+}
+
 static inline bool
 LogRollingEnabledIsValid(int enabled)
 {
