@@ -26,7 +26,10 @@
 
 
  ***************************************************************************/
-#include "ts/ink_platform.h"
+
+#include <memory>
+
+#include "tscore/ink_platform.h"
 
 #include "LogUtils.h"
 #include "LogFilter.h"
@@ -34,11 +37,10 @@
 #include "LogFormat.h"
 #include "LogFile.h"
 #include "LogBuffer.h"
-#include "LogHost.h"
 #include "LogObject.h"
 #include "LogConfig.h"
 #include "Log.h"
-#include "ts/SimpleTokenizer.h"
+#include "tscore/SimpleTokenizer.h"
 
 const char *LogFilter::OPERATOR_NAME[] = {"MATCH", "CASE_INSENSITIVE_MATCH", "CONTAIN", "CASE_INSENSITIVE_CONTAIN"};
 const char *LogFilter::ACTION_NAME[]   = {"REJECT", "ACCEPT", "WIPE_FIELD_VALUE"};
@@ -51,7 +53,7 @@ const char *LogFilter::ACTION_NAME[]   = {"REJECT", "ACCEPT", "WIPE_FIELD_VALUE"
   between the classes and I think should be removed.     ltavera
   -------------------------------------------------------------------------*/
 LogFilter::LogFilter(const char *name, LogField *field, LogFilter::Action action, LogFilter::Operator oper)
-  : m_name(ats_strdup(name)), m_field(NULL), m_action(action), m_operator(oper), m_type(INT_FILTER), m_num_values(0)
+  : m_name(ats_strdup(name)), m_field(nullptr), m_action(action), m_operator(oper), m_type(INT_FILTER), m_num_values(0)
 {
   m_field = new LogField(*field);
   ink_assert(m_field);
@@ -70,13 +72,13 @@ LogFilter *
 LogFilter::parse(const char *name, Action action, const char *condition)
 {
   SimpleTokenizer tok(condition);
-  ats_scoped_obj<LogField> logfield;
+  std::unique_ptr<LogField> logfield;
 
   ink_release_assert(action != N_ACTIONS);
 
   if (tok.getNumTokensRemaining() < 3) {
     Error("Invalid condition syntax '%s'; cannot create filter '%s'", condition, name);
-    return NULL;
+    return nullptr;
   }
 
   char *field_str = tok.getNext();
@@ -96,7 +98,7 @@ LogFilter::parse(const char *name, Action action, const char *condition)
   }
 
   if (LogField *f = Log::global_field_list.find_by_symbol(field_str)) {
-    logfield = new LogField(*f);
+    logfield.reset(new LogField(*f));
   }
 
   if (!logfield) {
@@ -109,9 +111,9 @@ LogFilter::parse(const char *name, Action action, const char *condition)
       char *fname_end;
 
       fname_end = strchr(field_str, '}');
-      if (NULL == fname_end) {
+      if (nullptr == fname_end) {
         Error("Invalid container field specification: no trailing '}' in '%s' cannot create filter '%s'", field_str, name);
-        return NULL;
+        return nullptr;
       }
 
       fname      = field_str + 1;
@@ -125,31 +127,31 @@ LogFilter::parse(const char *name, Action action, const char *condition)
       LogField::Container container = LogField::valid_container_name(cname);
       if (container == LogField::NO_CONTAINER) {
         Error("'%s' is not a valid container; cannot create filter '%s'", cname, name);
-        return NULL;
+        return nullptr;
       }
 
-      logfield = new LogField(fname, container);
-      ink_assert(logfield != NULL);
+      logfield.reset(new LogField(fname, container));
+      ink_assert(logfield != nullptr);
     }
   }
 
   if (!logfield) {
     Error("'%s' is not a valid field; cannot create filter '%s'", field_str, name);
-    return NULL;
+    return nullptr;
   }
 
   // convert the operator string to an enum value and validate it
   LogFilter::Operator oper = LogFilter::N_OPERATORS;
   for (unsigned i = 0; i < LogFilter::N_OPERATORS; ++i) {
     if (strcasecmp(oper_str, LogFilter::OPERATOR_NAME[i]) == 0) {
-      oper = (LogFilter::Operator)i;
+      oper = static_cast<LogFilter::Operator>(i);
       break;
     }
   }
 
   if (oper == LogFilter::N_OPERATORS) {
     Error("'%s' is not a valid operator; cannot create filter '%s'", oper_str, name);
-    return NULL;
+    return nullptr;
   }
 
   // now create the correct LogFilter
@@ -158,30 +160,30 @@ LogFilter::parse(const char *name, Action action, const char *condition)
 
   switch (field_type) {
   case LogField::sINT:
-    filter = new LogFilterInt(name, logfield, action, oper, val_str);
+    filter = new LogFilterInt(name, logfield.get(), action, oper, val_str);
     break;
 
   case LogField::dINT:
     Error("Invalid field type (double int); cannot create filter '%s'", name);
-    return NULL;
+    return nullptr;
 
   case LogField::STRING:
-    filter = new LogFilterString(name, logfield, action, oper, val_str);
+    filter = new LogFilterString(name, logfield.get(), action, oper, val_str);
     break;
 
   case LogField::IP:
-    filter = new LogFilterIP(name, logfield, action, oper, val_str);
+    filter = new LogFilterIP(name, logfield.get(), action, oper, val_str);
     break;
 
   default:
     Error("Unknown logging field type %d; cannot create filter '%s'", field_type, name);
-    return NULL;
+    return nullptr;
   }
 
   if (filter->get_num_values() == 0) {
     Error("'%s' does not specify any valid values; cannot create filter '%s'", val_str, name);
     delete filter;
-    return NULL;
+    return nullptr;
   }
 
   return filter;
@@ -203,7 +205,7 @@ LogFilterString::_setValues(size_t n, char **value)
     for (size_t i = 0; i < n; ++i) {
       m_value[i]           = ats_strdup(value[i]);
       m_length[i]          = strlen(value[i]);
-      m_value_uppercase[i] = (char *)ats_malloc((unsigned int)m_length[i] + 1);
+      m_value_uppercase[i] = static_cast<char *>(ats_malloc(static_cast<unsigned int>(m_length[i]) + 1));
       size_t j;
       for (j = 0; j < m_length[i]; ++j) {
         m_value_uppercase[i][j] = ParseRules::ink_toupper(m_value[i][j]);
@@ -219,14 +221,14 @@ LogFilterString::LogFilterString(const char *name, LogField *field, LogFilter::A
 {
   // parse the comma-separated list of values and construct array
   //
-  char **val_array = 0;
+  char **val_array = nullptr;
   size_t i         = 0;
   SimpleTokenizer tok(values, ',');
   size_t n = tok.getNumTokensRemaining();
   if (n) {
     val_array = new char *[n];
     char *t;
-    while (t = tok.getNext(), t != NULL) {
+    while (t = tok.getNext(), t != nullptr) {
       val_array[i++] = t;
     }
     if (i < n) {
@@ -308,26 +310,29 @@ LogFilterString::operator==(LogFilterString &rhs)
 bool
 LogFilterString::wipe_this_entry(LogAccess *lad)
 {
-  if (m_num_values == 0 || m_field == NULL || lad == NULL || m_action != WIPE_FIELD_VALUE) {
+  if (m_num_values == 0 || m_field == nullptr || lad == nullptr || m_action != WIPE_FIELD_VALUE) {
     return false;
   }
 
   static const unsigned BUFSIZE = 1024;
   char small_buf[BUFSIZE];
-  char *big_buf    = NULL;
-  char *buf        = small_buf;
-  size_t marsh_len = m_field->marshal_len(lad); // includes null termination
+  char small_buf_upper[BUFSIZE];
+  char *big_buf       = nullptr;
+  char *big_buf_upper = nullptr;
+  char *buf           = small_buf;
+  char *buf_upper     = small_buf_upper;
+  size_t marsh_len    = m_field->marshal_len(lad); // includes null termination
 
   if (marsh_len > BUFSIZE) {
-    big_buf = (char *)ats_malloc(marsh_len);
-    ink_assert(big_buf != NULL);
+    big_buf = static_cast<char *>(ats_malloc(marsh_len));
+    ink_assert(big_buf != nullptr);
     buf = big_buf;
   }
 
-  ink_assert(buf != NULL);
+  ink_assert(buf != nullptr);
   m_field->marshal(lad, buf);
 
-  ink_assert(buf != NULL);
+  ink_assert(buf != nullptr);
 
   bool cond_satisfied = false;
   switch (m_operator) {
@@ -340,27 +345,36 @@ LogFilterString::wipe_this_entry(LogAccess *lad)
     // actual length, so we just use the fact that a MATCH is not possible
     // when marsh_len <= (length of the filter string)
     //
-    cond_satisfied = _checkConditionAndWipe(&strcmp, &buf, marsh_len, m_value, DATA_LENGTH_LARGER);
+    cond_satisfied = _checkConditionAndWipe(&strcmp, &buf, marsh_len, m_value, nullptr, DATA_LENGTH_LARGER);
     break;
   case CASE_INSENSITIVE_MATCH:
-    cond_satisfied = _checkConditionAndWipe(&strcasecmp, &buf, marsh_len, m_value, DATA_LENGTH_LARGER);
+    cond_satisfied = _checkConditionAndWipe(&strcasecmp, &buf, marsh_len, m_value, nullptr, DATA_LENGTH_LARGER);
     break;
   case CONTAIN:
-    cond_satisfied = _checkConditionAndWipe(&_isSubstring, &buf, marsh_len, m_value, DATA_LENGTH_LARGER);
+    cond_satisfied = _checkConditionAndWipe(&_isSubstring, &buf, marsh_len, m_value, nullptr, DATA_LENGTH_LARGER);
     break;
   case CASE_INSENSITIVE_CONTAIN:
-    for (size_t i = 0; i < marsh_len; i++) {
-      buf[i] = ParseRules::ink_toupper(buf[i]);
+    if (big_buf) {
+      big_buf_upper = static_cast<char *>(ats_malloc(static_cast<unsigned int>(marsh_len)));
+      buf_upper     = big_buf_upper;
+    } else {
+      buf = small_buf; // make clang happy
     }
-    cond_satisfied = _checkConditionAndWipe(&_isSubstring, &buf, marsh_len, m_value_uppercase, DATA_LENGTH_LARGER);
+    for (size_t i = 0; i < marsh_len; i++) {
+      buf_upper[i] = ParseRules::ink_toupper(buf[i]);
+    }
+    cond_satisfied = _checkConditionAndWipe(&_isSubstring, &buf, marsh_len, m_value_uppercase, buf_upper, DATA_LENGTH_LARGER);
     break;
   default:
     ink_assert(!"INVALID FILTER OPERATOR");
   }
 
-  m_field->updateField(lad, buf, strlen(buf));
+  if (cond_satisfied) {
+    m_field->updateField(lad, buf, strlen(buf));
+  }
 
   ats_free(big_buf);
+  ats_free(big_buf_upper);
   return cond_satisfied;
 }
 
@@ -379,22 +393,22 @@ LogFilterString::wipe_this_entry(LogAccess *lad)
 bool
 LogFilterString::toss_this_entry(LogAccess *lad)
 {
-  if (m_num_values == 0 || m_field == NULL || lad == NULL) {
+  if (m_num_values == 0 || m_field == nullptr || lad == nullptr) {
     return false;
   }
 
   static const unsigned BUFSIZE = 1024;
   char small_buf[BUFSIZE];
   char small_buf_upper[BUFSIZE];
-  char *big_buf       = NULL;
-  char *big_buf_upper = NULL;
+  char *big_buf       = nullptr;
+  char *big_buf_upper = nullptr;
   char *buf           = small_buf;
   char *buf_upper     = small_buf_upper;
   size_t marsh_len    = m_field->marshal_len(lad); // includes null termination
 
   if (marsh_len > BUFSIZE) {
-    big_buf = (char *)ats_malloc((unsigned int)marsh_len);
-    ink_assert(big_buf != NULL);
+    big_buf = static_cast<char *>(ats_malloc(static_cast<unsigned int>(marsh_len)));
+    ink_assert(big_buf != nullptr);
     buf = big_buf;
   }
 
@@ -421,7 +435,7 @@ LogFilterString::toss_this_entry(LogAccess *lad)
     break;
   case CASE_INSENSITIVE_CONTAIN: {
     if (big_buf) {
-      big_buf_upper = (char *)ats_malloc((unsigned int)marsh_len);
+      big_buf_upper = static_cast<char *>(ats_malloc(static_cast<unsigned int>(marsh_len)));
       buf_upper     = big_buf_upper;
     } else {
       buf = small_buf; // make clang happy
@@ -449,7 +463,7 @@ LogFilterString::toss_this_entry(LogAccess *lad)
 void
 LogFilterString::display(FILE *fd)
 {
-  ink_assert(fd != NULL);
+  ink_assert(fd != nullptr);
   if (m_num_values == 0) {
     fprintf(fd, "Filter \"%s\" is inactive, no values specified\n", m_name);
   } else {
@@ -491,7 +505,7 @@ LogFilterInt::_convertStringToInt(char *value, int64_t *ival, LogFieldAliasMap *
     // value is an alias and try to get the actual integer value
     // from the log field alias map if field has one
     //
-    if (map == NULL || map->asInt(value, ival) != LogFieldAliasMap::ALL_OK) {
+    if (map == nullptr || map->asInt(value, ival) != LogFieldAliasMap::ALL_OK) {
       return -1; // error
     };
   } else {
@@ -523,17 +537,20 @@ LogFilterInt::LogFilterInt(const char *name, LogField *field, LogFilter::Action
 {
   // parse the comma-separated list of values and construct array
   //
-  int64_t *val_array = 0;
+  int64_t *val_array = nullptr;
   size_t i           = 0;
   SimpleTokenizer tok(values, ',');
   size_t n = tok.getNumTokensRemaining();
+  auto field_map{field->map()}; // because clang-analyzer freaks out if this is inlined.
+                                // It doesn't realize the value is held in place by the smart
+                                // pointer in @c field.
 
   if (n) {
     val_array = new int64_t[n];
     char *t;
-    while (t = tok.getNext(), t != NULL) {
+    while (t = tok.getNext(), t != nullptr) {
       int64_t ival;
-      if (!_convertStringToInt(t, &ival, field->map().get())) {
+      if (!_convertStringToInt(t, &ival, field_map.get())) {
         // conversion was successful, add entry to array
         //
         val_array[i++] = ival;
@@ -603,14 +620,14 @@ LogFilterInt::operator==(LogFilterInt &rhs)
 bool
 LogFilterInt::wipe_this_entry(LogAccess *lad)
 {
-  if (m_num_values == 0 || m_field == NULL || lad == NULL || m_action != WIPE_FIELD_VALUE) {
+  if (m_num_values == 0 || m_field == nullptr || lad == nullptr || m_action != WIPE_FIELD_VALUE) {
     return false;
   }
 
   bool cond_satisfied = false;
   int64_t value;
 
-  m_field->marshal(lad, (char *)&value);
+  m_field->marshal(lad, reinterpret_cast<char *>(&value));
   // This used to do an ntohl() on value, but that breaks various filters.
   // Long term we should move IPs to their own log type.
 
@@ -641,14 +658,14 @@ LogFilterInt::wipe_this_entry(LogAccess *lad)
 bool
 LogFilterInt::toss_this_entry(LogAccess *lad)
 {
-  if (m_num_values == 0 || m_field == NULL || lad == NULL) {
+  if (m_num_values == 0 || m_field == nullptr || lad == nullptr) {
     return false;
   }
 
   bool cond_satisfied = false;
   int64_t value;
 
-  m_field->marshal(lad, (char *)&value);
+  m_field->marshal(lad, reinterpret_cast<char *>(&value));
   // This used to do an ntohl() on value, but that breaks various filters.
   // Long term we should move IPs to their own log type.
 
@@ -679,7 +696,7 @@ LogFilterInt::toss_this_entry(LogAccess *lad)
 void
 LogFilterInt::display(FILE *fd)
 {
-  ink_assert(fd != NULL);
+  ink_assert(fd != nullptr);
   if (m_num_values == 0) {
     fprintf(fd, "Filter \"%s\" is inactive, no values specified\n", m_name);
   } else {
@@ -723,7 +740,7 @@ LogFilterIP::LogFilterIP(const char *name, LogField *field, LogFilter::Action ac
   char *t; // temp token pointer.
 
   if (n) {
-    while (t = tok.getNext(), t != NULL) {
+    while (t = tok.getNext(), t != nullptr) {
       IpAddr min, max;
       char *x = strchr(t, '-');
       if (x) {
@@ -757,8 +774,8 @@ LogFilterIP::LogFilterIP(const char *name, LogField *field, LogFilter::Action ac
 
 LogFilterIP::LogFilterIP(const LogFilterIP &rhs) : LogFilter(rhs.m_name, rhs.m_field, rhs.m_action, rhs.m_operator)
 {
-  for (IpMap::iterator spot(rhs.m_map.begin()), limit(rhs.m_map.end()); spot != limit; ++spot) {
-    m_map.mark(spot->min(), spot->max(), spot->data());
+  for (auto &spot : rhs.m_map) {
+    m_map.mark(spot.min(), spot.max(), spot.data());
   }
   this->init();
 }
@@ -767,16 +784,14 @@ void
 LogFilterIP::init()
 {
   m_type       = IP_FILTER;
-  m_num_values = m_map.getCount();
+  m_num_values = m_map.count();
 }
 
 /*-------------------------------------------------------------------------
   LogFilterIP::~LogFilterIP
   -------------------------------------------------------------------------*/
 
-LogFilterIP::~LogFilterIP()
-{
-}
+LogFilterIP::~LogFilterIP() = default;
 
 /*-------------------------------------------------------------------------
   LogFilterIP::operator==
@@ -821,11 +836,17 @@ LogFilterIP::is_match(LogAccess *lad)
   bool zret = false;
 
   if (m_field && lad) {
-    LogFieldIpStorage value;
-    m_field->marshal(lad, reinterpret_cast<char *>(&value));
-    // This is bad, we abuse the fact that the initial layout of LogFieldIpStorage and IpAddr
-    // are identical. We should look at converting the log stuff to use IpAddr directly.
-    zret = m_map.contains(reinterpret_cast<IpAddr &>(value));
+    LogFieldIpStorage field_ip_storage;
+    m_field->marshal(lad, reinterpret_cast<char *>(&field_ip_storage));
+
+    // Convert to the IpAddr type that the map holds.
+    IpAddr field_ip;
+    if (field_ip_storage._ip._family == AF_INET) {
+      field_ip = field_ip_storage._ip4._addr;
+    } else if (field_ip_storage._ip._family == AF_INET6) {
+      field_ip = field_ip_storage._ip6._addr;
+    }
+    zret = m_map.contains(field_ip);
   }
 
   return zret;
@@ -841,15 +862,7 @@ LogFilterIP::toss_this_entry(LogAccess *lad)
 bool
 LogFilterIP::wipe_this_entry(LogAccess *)
 {
-#if 0
-  bool zret = WIPE_FIELD_VALUE == m_action && this->is_match(lad);
-  if (zret) {
-    // set to ADDR_ANY.
-  }
-  return zret;
-#else
   return false;
-#endif
 }
 
 /*-------------------------------------------------------------------------
@@ -886,9 +899,9 @@ LogFilterIP::displayRanges(FILE *fd)
 void
 LogFilterIP::display(FILE *fd)
 {
-  ink_assert(fd != NULL);
+  ink_assert(fd != nullptr);
 
-  if (0 == m_map.getCount()) {
+  if (0 == m_map.count()) {
     fprintf(fd, "Filter \"%s\" is inactive, no values specified\n", m_name);
   } else {
     fprintf(fd, "Filter \"%s\" %sS records if %s %s ", m_name, ACTION_NAME[m_action], m_field->symbol(), OPERATOR_NAME[m_operator]);
@@ -929,9 +942,7 @@ filters_are_equal(LogFilter *filt1, LogFilter *filt2)
   add() function is overloaded for each sub-type of LogFilter.
   -------------------------------------------------------------------------*/
 
-LogFilterList::LogFilterList() : m_does_conjunction(true)
-{
-}
+LogFilterList::LogFilterList() = default;
 
 /*-------------------------------------------------------------------------
   -------------------------------------------------------------------------*/
@@ -986,7 +997,7 @@ LogFilterList::clear()
 void
 LogFilterList::add(LogFilter *filter, bool copy)
 {
-  ink_assert(filter != NULL);
+  ink_assert(filter != nullptr);
   if (copy) {
     if (filter->type() == LogFilter::INT_FILTER) {
       LogFilterInt *f = new LogFilterInt(*((LogFilterInt *)filter));
@@ -1049,14 +1060,14 @@ LogFilterList::toss_this_entry(LogAccess *lad)
   -------------------------------------------------------------------------*/
 
 LogFilter *
-LogFilterList::find_by_name(char *name)
+LogFilterList::find_by_name(const char *name)
 {
   for (LogFilter *f = first(); f; f = next(f)) {
     if (strcmp(f->name(), name) == 0) {
       return f;
     }
   }
-  return NULL;
+  return nullptr;
 }
 
 /*-------------------------------------------------------------------------
@@ -1082,7 +1093,7 @@ LogFilterList::display(FILE *fd)
 }
 
 #if TS_HAS_TESTS
-#include "ts/TestBox.h"
+#include "tscore/TestBox.h"
 
 REGRESSION_TEST(Log_FilterParse)(RegressionTest *t, int /* atype */, int *pstatus)
 {
@@ -1096,12 +1107,23 @@ REGRESSION_TEST(Log_FilterParse)(RegressionTest *t, int /* atype */, int *pstatu
   } while (0)
 
   *pstatus = REGRESSION_TEST_PASSED;
+  LogFilter *retfilter;
 
-  box.check(LogFilter::parse("t1", LogFilter::ACCEPT, "tok1 tok2") == NULL, "At least 3 tokens are required");
-  box.check(LogFilter::parse("t2", LogFilter::ACCEPT, "%<sym operator value") == NULL, "Unclosed symbol token");
-  box.check(LogFilter::parse("t3", LogFilter::ACCEPT, "%<{Age ssh> operator value") == NULL, "Unclosed container field");
-  box.check(LogFilter::parse("t4", LogFilter::ACCEPT, "%<james> operator value") == NULL, "Invalid log field");
-  box.check(LogFilter::parse("t5", LogFilter::ACCEPT, "%<chi> invalid value") == NULL, "Invalid operator name");
+  retfilter = LogFilter::parse("t1", LogFilter::ACCEPT, "tok1 tok2");
+  box.check(retfilter == nullptr, "At least 3 tokens are required");
+  delete retfilter;
+  retfilter = LogFilter::parse("t2", LogFilter::ACCEPT, "%<sym operator value");
+  box.check(retfilter == nullptr, "Unclosed symbol token");
+  delete retfilter;
+  retfilter = LogFilter::parse("t3", LogFilter::ACCEPT, "%<{Age ssh> operator value");
+  box.check(retfilter == nullptr, "Unclosed container field");
+  delete retfilter;
+  retfilter = LogFilter::parse("t4", LogFilter::ACCEPT, "%<james> operator value");
+  box.check(retfilter == nullptr, "Invalid log field");
+  delete retfilter;
+  retfilter = LogFilter::parse("t5", LogFilter::ACCEPT, "%<chi> invalid value");
+  box.check(retfilter == nullptr, "Invalid operator name");
+  delete retfilter;
 
   CHECK_FORMAT_PARSE("pssc MATCH 200");
   CHECK_FORMAT_PARSE("shn CASE_INSENSITIVE_CONTAIN unwanted.com");
