@@ -21,14 +21,12 @@
   limitations under the License.
  */
 
-#ifndef LOG_FORMAT_H
-#define LOG_FORMAT_H
+#pragma once
 
 #define LOG_FIELD_MARKER '\377'
 
-#include "ts/ink_platform.h"
+#include "tscore/ink_platform.h"
 #include "LogField.h"
-#include "InkXml.h"
 
 enum LogFormatType {
   // We start the numbering at 4 to compatibility with Traffic Server 4.x, which used
@@ -51,17 +49,16 @@ enum LogFileFormat {
   which is defined as a set of fields.
   -------------------------------------------------------------------------*/
 
-class LogFormat
+class LogFormat : public RefCountObj
 {
 public:
-  LogFormat(const char *name, const char *format_str, unsigned interval_sec = 0);
+  LogFormat(const char *name, const char *format_str, unsigned interval_sec = 0, LogEscapeType escape_type = LOG_ESCAPE_NONE);
   LogFormat(const char *name, const char *fieldlist_str, const char *printf_str, unsigned interval_sec = 0);
   LogFormat(const LogFormat &rhs);
 
-  ~LogFormat();
+  ~LogFormat() override;
 
   void display(FILE *fd = stdout);
-  void displayAsXML(FILE *fd = stdout);
 
   bool
   valid() const
@@ -98,6 +95,11 @@ public:
   {
     return m_format_type;
   }
+  LogEscapeType
+  escape_type() const
+  {
+    return m_escape_type;
+  }
   char *
   printf_str() const
   {
@@ -161,14 +163,17 @@ private:
   bool m_aggregate;
   char *m_format_str;
   LogFormatType m_format_type;
+  LogEscapeType m_escape_type;
 
 public:
   LINK(LogFormat, link);
 
+  // noncopyable
+  LogFormat &operator=(LogFormat &rhs) = delete;
+
 private:
   // -- member functions that are not allowed --
   LogFormat();
-  LogFormat &operator=(LogFormat &rhs);
 };
 
 // For text logs, there is no format string; we'll simply log the
@@ -177,7 +182,7 @@ private:
 static inline LogFormat *
 MakeTextLogFormat(const char *name = "text")
 {
-  return new LogFormat(name, NULL /* format_str */);
+  return new LogFormat(name, nullptr /* format_str */);
 }
 
 /*-------------------------------------------------------------------------
@@ -208,12 +213,11 @@ public:
   unsigned count();
   void display(FILE *fd = stdout);
 
+  // noncopyable
+  // -- member functions that are not allowed --
+  LogFormatList(const LogFormatList &rhs) = delete;
+  LogFormatList &operator=(const LogFormatList &rhs) = delete;
+
 private:
   Queue<LogFormat> m_format_list;
-
-  // -- member functions that are not allowed --
-  LogFormatList(const LogFormatList &rhs);
-  LogFormatList &operator=(const LogFormatList &rhs);
 };
-
-#endif
