@@ -21,27 +21,27 @@
   limitations under the License.
  */
 
-#ifndef __DIAGSCONFIG_H__
-#define __DIAGSCONFIG_H__
-#include "ts/Diags.h"
-#include "ts/BaseLogFile.h"
+#pragma once
+
+#include "tscore/Diags.h"
+#include "tscore/BaseLogFile.h"
 
 struct DiagsConfig {
   void reconfigure_diags();
   void config_diags_norecords();
   void parse_output_string(char *s, DiagsModeOutput *o);
-  void RegisterDiagConfig();
   void register_diags_callbacks();
 
-  DiagsConfig(const char *filename, const char *tags, const char *actions, bool use_records = true);
+  /** DiagsConfig constructor.
+   *
+   * As a side effect, this sets the global diags pointer to newly
+   * constructed _diags value.
+   */
+  DiagsConfig(std::string_view prefix_string, const char *filename, const char *tags, const char *actions, bool use_records = true);
   ~DiagsConfig();
 
 private:
   bool callbacks_established;
   BaseLogFile *diags_log;
-
-public:
-  Diags *diags;
+  Diags *_diags;
 };
-
-#endif
